/********************************************************************************
 * @(#)regxc2310s.xml	1.8
 * 
 * Origin: P11ULE_TS_SFR_20101006.xml
 * Rev: 20101006, TS Rev 1.4
 * Device: P11ULE
 * Family: P11
 * 
 * Copyright 2008-2011 Altium BV
 *
 * Define the following macros to exclude part of the
 * list of defined registers and register bits
 *
 *
 * This header file contains definitions for registers outside
 * DPP3. These register cannot safely be accessed using _near
 * addressing mode. For this reason, they are defined as
 * _far volatile unsigned int (*<address>);
 *
 * If a DPPx register is allocated to point to the required areas,
 * these registers can also be accessed using near addressing mode.
 * To enable this, define the following macro to the allocated DPP
 * register to convert the far addresses to near address on a
 * per-page basis:
 *
 *	PAGE_3FF_REGISTERS_NEAR               Memory range 0xFFC000 - 0xFFFFFF
 *	PAGE_081_REGISTERS_NEAR               Memory range 0x204000 - 0x207FFF
 *	PAGE_102_REGISTERS_NEAR               Memory range 0x408000 - 0x40BFFF
 *	PAGE_103_REGISTERS_NEAR               Memory range 0x40C000 - 0x40FFFF
 *
********************************************************************************/

#ifndef REGXC2310S_INC
#define REGXC2310S_INC

#define _FIX_DPP(dpp,pof)	( ( (unsigned int) dpp<<14 ) | ( (unsigned int) pof & 0x3FFF ) )

#ifdef PAGE_3FF_REGISTERS_NEAR
# if _MODEL == 't' || _MODEL == 's'
#  define _PAGE_3FF_MEM_TYPE(addr)       ((unsigned volatile int _near*)_FIX_DPP(PAGE_3FF_REGISTERS_NEAR,addr))
#  if   PAGE_3FF_REGISTERS_NEAR < 0 || PAGE_3FF_REGISTERS_NEAR > 2
#   error "PAGE_3FF_REGISTERS_NEAR is not defined to a valid DPP register"
#  endif
# else
#  if PAGE_3FF_REGISTERS_NEAR == 1
#    define _PAGE_3FF_MEM_TYPE(addr)    ((unsigned volatile int _xnear*)_FIX_DPP(1,addr))
#  elif PAGE_3FF_REGISTERS_NEAR == 2
#    define _PAGE_3FF_MEM_TYPE(addr)    ((unsigned volatile int _near*)_FIX_DPP(2,addr))
#  else
#   error "PAGE_3FF_REGISTERS_NEAR is not defined to a valid DPP register"
#  endif
# endif
#else
# define _PAGE_3FF_MEM_TYPE(addr)       ((unsigned volatile int _far *)addr)
#endif

#ifdef PAGE_081_REGISTERS_NEAR
# if _MODEL == 't' || _MODEL == 's'
#  define _PAGE_081_MEM_TYPE(addr)       ((unsigned volatile int _near*)_FIX_DPP(PAGE_081_REGISTERS_NEAR,addr))
#  if   PAGE_081_REGISTERS_NEAR < 0 || PAGE_081_REGISTERS_NEAR > 2
#   error "PAGE_081_REGISTERS_NEAR is not defined to a valid DPP register"
#  endif
# else
#  if PAGE_081_REGISTERS_NEAR == 1
#    define _PAGE_081_MEM_TYPE(addr)    ((unsigned volatile int _xnear*)_FIX_DPP(1,addr))
#  elif PAGE_081_REGISTERS_NEAR == 2
#    define _PAGE_081_MEM_TYPE(addr)    ((unsigned volatile int _near*)_FIX_DPP(2,addr))
#  else
#   error "PAGE_081_REGISTERS_NEAR is not defined to a valid DPP register"
#  endif
# endif
#else
# define _PAGE_081_MEM_TYPE(addr)       ((unsigned volatile int _far *)addr)
#endif

#ifdef PAGE_102_REGISTERS_NEAR
# if _MODEL == 't' || _MODEL == 's'
#  define _PAGE_102_MEM_TYPE(addr)       ((unsigned volatile int _near*)_FIX_DPP(PAGE_102_REGISTERS_NEAR,addr))
#  if   PAGE_102_REGISTERS_NEAR < 0 || PAGE_102_REGISTERS_NEAR > 2
#   error "PAGE_102_REGISTERS_NEAR is not defined to a valid DPP register"
#  endif
# else
#  if PAGE_102_REGISTERS_NEAR == 1
#    define _PAGE_102_MEM_TYPE(addr)    ((unsigned volatile int _xnear*)_FIX_DPP(1,addr))
#  elif PAGE_102_REGISTERS_NEAR == 2
#    define _PAGE_102_MEM_TYPE(addr)    ((unsigned volatile int _near*)_FIX_DPP(2,addr))
#  else
#   error "PAGE_102_REGISTERS_NEAR is not defined to a valid DPP register"
#  endif
# endif
#else
# define _PAGE_102_MEM_TYPE(addr)       ((unsigned volatile int _far *)addr)
#endif

#ifdef PAGE_103_REGISTERS_NEAR
# if _MODEL == 't' || _MODEL == 's'
#  define _PAGE_103_MEM_TYPE(addr)       ((unsigned volatile int _near*)_FIX_DPP(PAGE_103_REGISTERS_NEAR,addr))
#  if   PAGE_103_REGISTERS_NEAR < 0 || PAGE_103_REGISTERS_NEAR > 2
#   error "PAGE_103_REGISTERS_NEAR is not defined to a valid DPP register"
#  endif
# else
#  if PAGE_103_REGISTERS_NEAR == 1
#    define _PAGE_103_MEM_TYPE(addr)    ((unsigned volatile int _xnear*)_FIX_DPP(1,addr))
#  elif PAGE_103_REGISTERS_NEAR == 2
#    define _PAGE_103_MEM_TYPE(addr)    ((unsigned volatile int _near*)_FIX_DPP(2,addr))
#  else
#   error "PAGE_103_REGISTERS_NEAR is not defined to a valid DPP register"
#  endif
# endif
#else
# define _PAGE_103_MEM_TYPE(addr)       ((unsigned volatile int _far *)addr)
#endif


/********************************************************************************
 * Core Registers
********************************************************************************/
#ifndef REGXC2310S_NOCPU

_sfr CPUCON1;                           /* CPU Control Register 1 */

_sfr CPUCON2;                           /* CPU Control Register 2 */

_sfr CP;                                /* Context Pointer */

_sfr CSP;                               /* Code Segment Pointer */

_sfr DPP0;                              /* Data Page Pointer 0 */

_sfr DPP1;                              /* Data Page Pointer 1 */

_sfr DPP2;                              /* Data Page Pointer 2 */

_sfr DPP3;                              /* Data Page Pointer 3 */

_esfr QR0;                              /* Offset Register */

_esfr QR1;                              /* Offset Register */

_sfr IDX0;                              /* Address Pointer */

_sfr IDX1;                              /* Address Pointer */

_esfr QX0;                              /* Offset Register */

_esfr QX1;                              /* Offset Register */

_sfr SP;                                /* Stack Pointer */

_sfr SPSEG;                             /* Stack Pointer Segment */

_sfr STKOV;                             /* Stack Overflow Register */

_sfr STKUN;                             /* Stack Underflow Register */

_sfr PSW;                               /* Process Status Word */
_sfrbit PSW_N;                          /* PSW.0: Negative Result */
_sfrbit PSW_C;                          /* PSW.1: Carry Flag */
_sfrbit PSW_V;                          /* PSW.2: Overflow Result */
_sfrbit PSW_Z;                          /* PSW.3: Zero Flag */
_sfrbit PSW_E;                          /* PSW.4: End of Table Flag */
_sfrbit PSW_PL0;                        /* PSW.5: Protection Level selection 0 */
_sfrbit PSW_USR0;                       /* PSW.6: User General Purpose Flag */
_sfrbit PSW_USR1;                       /* PSW.7: User General Purpose Flag */
_sfrbit PSW_HLDEN_PL1;                  /* PSW.10: HOLD Enable / Protection Level selection 1 */
_sfrbit PSW_IEN;                        /* PSW.11: Interrupt Enable Control Bit */

#define N               PSW_N
#define C               PSW_C
#define V               PSW_V
#define Z               PSW_Z
#define E               PSW_E
#define MULIP           PSW_HLDEN_PL1
#define USR0            PSW_USR0
#define USR1            PSW_USR1
#define HLDEN           PSW_HLDEN_PL1
#define IEN             PSW_IEN

_sfr MDH;                               /* Multiply/Devide High Register */

_sfr MDL;                               /* Multiply/Devide Low Register */

_sfr MDC;                               /* Multiply/Devide Control Register */
_sfrbit MDC_MDRIU;                      /* MDC.4: Multiply/Devide Register in Use */

#define MDRIU           MDC_MDRIU

_sfr MCW;                               /* MAC Control Word */
_sfrbit MCW_MS;                         /* MCW.9: Saturation Mode Control */
_sfrbit MCW_MP;                         /* MCW.10: One-bit Scaler Control */

#define MS              MCW_MS
#define MP              MCW_MP

_sfr MAL;                               /* Accumulator Low Word */

_sfr MAH;                               /* Accumulator High Word */

_sfr MSW;                               /* MAC Status Word */
_sfrbit MSW_MN;                         /* MSW.8: Negative Result */
_sfrbit MSW_MZ;                         /* MSW.9: Zero Flag */
_sfrbit MSW_MC;                         /* MSW.10: Carry Flag */
_sfrbit MSW_MSV;                        /* MSW.11: Sticky Overflow Flag */
_sfrbit MSW_ME;                         /* MSW.12: MAC Extension Flag */
_sfrbit MSW_MSL;                        /* MSW.13: Sticky Limit Flag */
_sfrbit MSW_MV;                         /* MSW.14: Overflow Flag */

#define MN              MSW_MN
#define MZ              MSW_MZ
#define MC              MSW_MC
#define MSV             MSW_MSV
#define ME              MSW_ME
#define MSL             MSW_MSL
#define MV              MSW_MV

_sfr MRW;                               /* MAC Repeater Word */

_sfr ZEROS;                             /* Zeros Register */

_sfr ONES;                              /* Ones Register */

_esfr CPUID;                            /* CPU Identification Register */

#endif /* REGXC2310S_NOCPU */

/********************************************************************************
 * MPU
********************************************************************************/
#ifndef REGXC2310S_NOMPU

_sfr MPU_PM0;                           /* Protection Mode Register 0 */
_sfrbit MPU_PM0_PROTEN;                 /* MPU_PM0.0: Protection Enable bit */
_sfrbit MPU_PM0_XEA;                    /* MPU_PM0.1: Execute Enable */
_sfrbit MPU_PM0_REA;                    /* MPU_PM0.2: Read Enable */
_sfrbit MPU_PM0_WEA;                    /* MPU_PM0.3: Write Enable */
_sfrbit MPU_PM0_L0EA;                   /* MPU_PM0.4: Level 0 Enable */
_sfrbit MPU_PM0_L1EA;                   /* MPU_PM0.5: Level 1 Enable */
_sfrbit MPU_PM0_L2EA;                   /* MPU_PM0.6: Level 2 Enable */
_sfrbit MPU_PM0_L3EA;                   /* MPU_PM0.7: Level 3 Enable */
_sfrbit MPU_PM0_XEB;                    /* MPU_PM0.9: Execute Enable */
_sfrbit MPU_PM0_REB;                    /* MPU_PM0.10: Read Enable */
_sfrbit MPU_PM0_WEB;                    /* MPU_PM0.11: Write Enable */
_sfrbit MPU_PM0_L0EB;                   /* MPU_PM0.12: Level 0 Enable */
_sfrbit MPU_PM0_L1EB;                   /* MPU_PM0.13: Level 1 Enable */
_sfrbit MPU_PM0_L2EB;                   /* MPU_PM0.14: Level 2 Enable */
_sfrbit MPU_PM0_L3EB;                   /* MPU_PM0.15: Level 3 Enable */

_sfr MPU_PM1;                           /* Protection Mode Register 1 */
_sfrbit MPU_PM1_XEA;                    /* MPU_PM1.1: Execute Enable */
_sfrbit MPU_PM1_REA;                    /* MPU_PM1.2: Read Enable */
_sfrbit MPU_PM1_WEA;                    /* MPU_PM1.3: Write Enable */
_sfrbit MPU_PM1_L0EA;                   /* MPU_PM1.4: Level 0 Enable */
_sfrbit MPU_PM1_L1EA;                   /* MPU_PM1.5: Level 1 Enable */
_sfrbit MPU_PM1_L2EA;                   /* MPU_PM1.6: Level 2 Enable */
_sfrbit MPU_PM1_L3EA;                   /* MPU_PM1.7: Level 3 Enable */
_sfrbit MPU_PM1_XEB;                    /* MPU_PM1.9: Execute Enable */
_sfrbit MPU_PM1_REB;                    /* MPU_PM1.10: Read Enable */
_sfrbit MPU_PM1_WEB;                    /* MPU_PM1.11: Write Enable */
_sfrbit MPU_PM1_L0EB;                   /* MPU_PM1.12: Level 0 Enable */
_sfrbit MPU_PM1_L1EB;                   /* MPU_PM1.13: Level 1 Enable */
_sfrbit MPU_PM1_L2EB;                   /* MPU_PM1.14: Level 2 Enable */
_sfrbit MPU_PM1_L3EB;                   /* MPU_PM1.15: Level 3 Enable */

_sfr MPU_PM2;                           /* Protection Mode Register 2 */
_sfrbit MPU_PM2_XEA;                    /* MPU_PM2.1: Execute Enable */
_sfrbit MPU_PM2_REA;                    /* MPU_PM2.2: Read Enable */
_sfrbit MPU_PM2_WEA;                    /* MPU_PM2.3: Write Enable */
_sfrbit MPU_PM2_L0EA;                   /* MPU_PM2.4: Level 0 Enable */
_sfrbit MPU_PM2_L1EA;                   /* MPU_PM2.5: Level 1 Enable */
_sfrbit MPU_PM2_L2EA;                   /* MPU_PM2.6: Level 2 Enable */
_sfrbit MPU_PM2_L3EA;                   /* MPU_PM2.7: Level 3 Enable */
_sfrbit MPU_PM2_XEB;                    /* MPU_PM2.9: Execute Enable */
_sfrbit MPU_PM2_REB;                    /* MPU_PM2.10: Read Enable */
_sfrbit MPU_PM2_WEB;                    /* MPU_PM2.11: Write Enable */
_sfrbit MPU_PM2_L0EB;                   /* MPU_PM2.12: Level 0 Enable */
_sfrbit MPU_PM2_L1EB;                   /* MPU_PM2.13: Level 1 Enable */
_sfrbit MPU_PM2_L2EB;                   /* MPU_PM2.14: Level 2 Enable */
_sfrbit MPU_PM2_L3EB;                   /* MPU_PM2.15: Level 3 Enable */

_sfr MPU_PM3;                           /* Protection Mode Register 3 */
_sfrbit MPU_PM3_XEA;                    /* MPU_PM3.1: Execute Enable */
_sfrbit MPU_PM3_REA;                    /* MPU_PM3.2: Read Enable */
_sfrbit MPU_PM3_WEA;                    /* MPU_PM3.3: Write Enable */
_sfrbit MPU_PM3_L0EA;                   /* MPU_PM3.4: Level 0 Enable */
_sfrbit MPU_PM3_L1EA;                   /* MPU_PM3.5: Level 1 Enable */
_sfrbit MPU_PM3_L2EA;                   /* MPU_PM3.6: Level 2 Enable */
_sfrbit MPU_PM3_L3EA;                   /* MPU_PM3.7: Level 3 Enable */
_sfrbit MPU_PM3_XEB;                    /* MPU_PM3.9: Execute Enable */
_sfrbit MPU_PM3_REB;                    /* MPU_PM3.10: Read Enable */
_sfrbit MPU_PM3_WEB;                    /* MPU_PM3.11: Write Enable */
_sfrbit MPU_PM3_L0EB;                   /* MPU_PM3.12: Level 0 Enable */
_sfrbit MPU_PM3_L1EB;                   /* MPU_PM3.13: Level 1 Enable */
_sfrbit MPU_PM3_L2EB;                   /* MPU_PM3.14: Level 2 Enable */
_sfrbit MPU_PM3_L3EB;                   /* MPU_PM3.15: Level 3 Enable */

_sfr MPU_PM4;                           /* Protection Mode Register 4 */
_sfrbit MPU_PM4_XEA;                    /* MPU_PM4.1: Execute Enable */
_sfrbit MPU_PM4_REA;                    /* MPU_PM4.2: Read Enable */
_sfrbit MPU_PM4_WEA;                    /* MPU_PM4.3: Write Enable */
_sfrbit MPU_PM4_L0EA;                   /* MPU_PM4.4: Level 0 Enable */
_sfrbit MPU_PM4_L1EA;                   /* MPU_PM4.5: Level 1 Enable */
_sfrbit MPU_PM4_L2EA;                   /* MPU_PM4.6: Level 2 Enable */
_sfrbit MPU_PM4_L3EA;                   /* MPU_PM4.7: Level 3 Enable */
_sfrbit MPU_PM4_XEB;                    /* MPU_PM4.9: Execute Enable */
_sfrbit MPU_PM4_REB;                    /* MPU_PM4.10: Read Enable */
_sfrbit MPU_PM4_WEB;                    /* MPU_PM4.11: Write Enable */
_sfrbit MPU_PM4_L0EB;                   /* MPU_PM4.12: Level 0 Enable */
_sfrbit MPU_PM4_L1EB;                   /* MPU_PM4.13: Level 1 Enable */
_sfrbit MPU_PM4_L2EB;                   /* MPU_PM4.14: Level 2 Enable */
_sfrbit MPU_PM4_L3EB;                   /* MPU_PM4.15: Level 3 Enable */

_sfr MPU_PM5;                           /* Protection Mode Register 5 */
_sfrbit MPU_PM5_XEA;                    /* MPU_PM5.1: Execute Enable */
_sfrbit MPU_PM5_REA;                    /* MPU_PM5.2: Read Enable */
_sfrbit MPU_PM5_WEA;                    /* MPU_PM5.3: Write Enable */
_sfrbit MPU_PM5_L0EA;                   /* MPU_PM5.4: Level 0 Enable */
_sfrbit MPU_PM5_L1EA;                   /* MPU_PM5.5: Level 1 Enable */
_sfrbit MPU_PM5_L2EA;                   /* MPU_PM5.6: Level 2 Enable */
_sfrbit MPU_PM5_L3EA;                   /* MPU_PM5.7: Level 3 Enable */
_sfrbit MPU_PM5_XEB;                    /* MPU_PM5.9: Execute Enable */
_sfrbit MPU_PM5_REB;                    /* MPU_PM5.10: Read Enable */
_sfrbit MPU_PM5_WEB;                    /* MPU_PM5.11: Write Enable */
_sfrbit MPU_PM5_L0EB;                   /* MPU_PM5.12: Level 0 Enable */
_sfrbit MPU_PM5_L1EB;                   /* MPU_PM5.13: Level 1 Enable */
_sfrbit MPU_PM5_L2EB;                   /* MPU_PM5.14: Level 2 Enable */
_sfrbit MPU_PM5_L3EB;                   /* MPU_PM5.15: Level 3 Enable */

_sfr MPU_PRD;                           /* Protection Range Data */

_sfr MPU_PRA;                           /* Protection Range Address */
_sfrbit MPU_PRA_WWA;                    /* MPU_PRA.6: Write Wrap Around Status */
_sfrbit MPU_PRA_WMOD;                   /* MPU_PRA.7: Auto increment Write Mode */
_sfrbit MPU_PRA_RWA;                    /* MPU_PRA.14: Read Wrap Around Status */
_sfrbit MPU_PRA_RMOD;                   /* MPU_PRA.15: Auto increment Read Mode */

#endif /* REGXC2310S_NOMPU */

/********************************************************************************
 * MCHK
********************************************************************************/
#ifndef REGXC2310S_NOMCHK

_sfr MCHK_ID;                           /* Module Identification Register */

_sfr MCHK_IR;                           /* Input Register */

_esfr MCHK_RRL;                         /* Result Register Low */

_esfr MCHK_RRH;                         /* Result Register High */

_sfr MCHK_COUNT;                        /* Count Register */

_esfr MCHK_TPRL;                        /* Tap Polynomial Register Low */

_esfr MCHK_TPRH;                        /* Tap Polynomial Register High */

#endif /* REGXC2310S_NOMCHK */

/********************************************************************************
 * Interrupt registers
********************************************************************************/
#ifndef REGXC2310S_NOINTERRUPT

_sfr VECSEG;                            /* Vector Segment Pointer */

_xsfr FINT0CSP;                         /* Fast Interrupt Control 0 */

_xsfr FINT1CSP;                         /* Fast Interrupt Control 1 */

_xsfr FINT0ADDR;                        /* Fast Interrupt Address 0 */

_xsfr FINT1ADDR;                        /* Fast Interrupt Address 1 */

_xsfr BNKSEL0;                          /* Register Bank Selection 0 */

_xsfr BNKSEL1;                          /* Register Bank Selection 1 */

_xsfr BNKSEL2;                          /* Register Bank Selection 2 */

_xsfr BNKSEL3;                          /* Register Bank Selection 3 */

_sfr TFR;                               /* Trap Flag Register */
_sfrbit TFR_ILLOPA;                     /* TFR.2: Illegal word operand access */
_sfrbit TFR_PRTFLT;                     /* TFR.3: Protection Fault */
_sfrbit TFR_ACER;                       /* TFR.4: Memory Access Error */
_sfrbit TFR_UNDOPC;                     /* TFR.7: Undefined Opcode */
_sfrbit TFR_MPX;                        /* TFR.8: Memory Protection Execute */
_sfrbit TFR_MPW;                        /* TFR.9: Memory Protection Write */
_sfrbit TFR_MPR;                        /* TFR.10: Memory Protection Read */
_sfrbit TFR_SR1;                        /* TFR.11: System request flag 1 */
_sfrbit TFR_SOFTBRK;                    /* TFR.12: Software Break */
_sfrbit TFR_STKUF;                      /* TFR.13: Stack underflow flag */
_sfrbit TFR_STKOF;                      /* TFR.14: Stack overflow flag */
_sfrbit TFR_SR0;                        /* TFR.15: System request flag 0 */

_xsfr SRCP0;                            /* PEC Source Pointer 0 */

_xsfr SRCP1;                            /* PEC Source Pointer 1 */

_xsfr SRCP2;                            /* PEC Source Pointer 2 */

_xsfr SRCP3;                            /* PEC Source Pointer 3 */

_xsfr SRCP4;                            /* PEC Source Pointer 4 */

_xsfr SRCP5;                            /* PEC Source Pointer 5 */

_xsfr SRCP6;                            /* PEC Source Pointer 6 */

_xsfr SRCP7;                            /* PEC Source Pointer 7 */

_xsfr DSTP0;                            /* PEC Destination Pointer 0 */

_xsfr DSTP1;                            /* PEC Destination Pointer 1 */

_xsfr DSTP2;                            /* PEC Destination Pointer 2 */

_xsfr DSTP3;                            /* PEC Destination Pointer 3 */

_xsfr DSTP4;                            /* PEC Destination Pointer 4 */

_xsfr DSTP5;                            /* PEC Destination Pointer 5 */

_xsfr DSTP6;                            /* PEC Destination Pointer 6 */

_xsfr DSTP7;                            /* PEC Destination Pointer 7 */

_xsfr PECSEG0;                          /* PEC Segment Pointer 0 */

_xsfr PECSEG1;                          /* PEC Segment Pointer 1 */

_xsfr PECSEG2;                          /* PEC Segment Pointer 2 */

_xsfr PECSEG3;                          /* PEC Segment Pointer 3 */

_xsfr PECSEG4;                          /* PEC Segment Pointer 4 */

_xsfr PECSEG5;                          /* PEC Segment Pointer 5 */

_xsfr PECSEG6;                          /* PEC Segment Pointer 6 */

_xsfr PECSEG7;                          /* PEC Segment Pointer 7 */

_sfr PECC0;                             /* PEC Channel Control 0 */

_sfr PECC1;                             /* PEC Channel Control 1 */

_sfr PECC2;                             /* PEC Channel Control 2 */

_sfr PECC3;                             /* PEC Channel Control 3 */

_sfr PECC4;                             /* PEC Channel Control 4 */

_sfr PECC5;                             /* PEC Channel Control 5 */

_sfr PECC6;                             /* PEC Channel Control 6 */

_sfr PECC7;                             /* PEC Channel Control 7 */

_esfr EOPIC;                            /* End Of PEC Interrupt Control */
_esfrbit EOPIC_EOPIE;                   /* EOPIC.6: Interrupt Enable Control Bit */
_esfrbit EOPIC_EOPIR;                   /* EOPIC.7: Interrupt Request Flag */
_esfrbit EOPIC_GPX;                     /* EOPIC.8: Group Priority Extension */

_sfr PECISNC;                           /* PEC Interrupt Sub Node Control */
_sfrbit PECISNC_C0IE;                   /* PECISNC.0: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECISNC_C0IR;                   /* PECISNC.1: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECISNC_C1IE;                   /* PECISNC.2: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECISNC_C1IR;                   /* PECISNC.3: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECISNC_C2IE;                   /* PECISNC.4: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECISNC_C2IR;                   /* PECISNC.5: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECISNC_C3IE;                   /* PECISNC.6: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECISNC_C3IR;                   /* PECISNC.7: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECISNC_C4IE;                   /* PECISNC.8: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECISNC_C4IR;                   /* PECISNC.9: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECISNC_C5IE;                   /* PECISNC.10: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECISNC_C5IR;                   /* PECISNC.11: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECISNC_C6IE;                   /* PECISNC.12: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECISNC_C6IR;                   /* PECISNC.13: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECISNC_C7IE;                   /* PECISNC.14: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECISNC_C7IR;                   /* PECISNC.15: Interrupt Sub Node Request Flag of PEC Channel x */

_sfr SCU_ISSR;                          /* Interrupt Source Select Register */
_sfrbit SCU_ISSR_ISS0;                  /* SCU_ISSR.0: Interrupt Source Select for CC2_CC16IC */
_sfrbit SCU_ISSR_ISS1;                  /* SCU_ISSR.1: Interrupt Source Select for CC2_CC17IC */
_sfrbit SCU_ISSR_ISS2;                  /* SCU_ISSR.2: Interrupt Source Select for CC2_CC18IC */
_sfrbit SCU_ISSR_ISS3;                  /* SCU_ISSR.3: Interrupt Source Select for CC2_CC19IC */
_sfrbit SCU_ISSR_ISS4;                  /* SCU_ISSR.4: Interrupt Source Select for CC2_CC20IC */
_sfrbit SCU_ISSR_ISS5;                  /* SCU_ISSR.5: Interrupt Source Select for CC2_CC21IC */
_sfrbit SCU_ISSR_ISS6;                  /* SCU_ISSR.6: Interrupt Source Select for CC2_CC22IC */
_sfrbit SCU_ISSR_ISS7;                  /* SCU_ISSR.7: Interrupt Source Select for CC2_CC23IC */
_sfrbit SCU_ISSR_ISS8;                  /* SCU_ISSR.8: Interrupt Source Select for CC2_CC24IC */
_sfrbit SCU_ISSR_ISS9;                  /* SCU_ISSR.9: Interrupt Source Select for CC2_CC25IC */
_sfrbit SCU_ISSR_ISS10;                 /* SCU_ISSR.10: Interrupt Source Select for CC2_CC26IC */
_sfrbit SCU_ISSR_ISS11;                 /* SCU_ISSR.11: Interrupt Source Select for CC2_CC27IC */
_sfrbit SCU_ISSR_ISS12;                 /* SCU_ISSR.12: Interrupt Source Select for CC2_CC28IC */
_sfrbit SCU_ISSR_ISS13;                 /* SCU_ISSR.13: Interrupt Source Select for CC2_CC29IC */
_sfrbit SCU_ISSR_ISS14;                 /* SCU_ISSR.14: Interrupt Source Select for CC2_CC30IC */
_sfrbit SCU_ISSR_ISS15;                 /* SCU_ISSR.15: Interrupt Source Select for CC2_CC31IC */

_sfr ADC_0IC;                           /* ADC Interrupt Control 0 */
_sfrbit ADC_0IC_IE;                     /* ADC_0IC.6: Interrupt Enable Control Bit */
_sfrbit ADC_0IC_IR;                     /* ADC_0IC.7: Interrupt Request Flag */
_sfrbit ADC_0IC_GPX;                    /* ADC_0IC.8: Group Priority Extension */

_sfr ADC_1IC;                           /* ADC Interrupt Control 1 */
_sfrbit ADC_1IC_IE;                     /* ADC_1IC.6: Interrupt Enable Control Bit */
_sfrbit ADC_1IC_IR;                     /* ADC_1IC.7: Interrupt Request Flag */
_sfrbit ADC_1IC_GPX;                    /* ADC_1IC.8: Group Priority Extension */

_sfr ADC_2IC;                           /* ADC Interrupt Control 2 */
_sfrbit ADC_2IC_IE;                     /* ADC_2IC.6: Interrupt Enable Control Bit */
_sfrbit ADC_2IC_IR;                     /* ADC_2IC.7: Interrupt Request Flag */
_sfrbit ADC_2IC_GPX;                    /* ADC_2IC.8: Group Priority Extension */

_sfr ADC_3IC;                           /* ADC Interrupt Control 3 */
_sfrbit ADC_3IC_IE;                     /* ADC_3IC.6: Interrupt Enable Control Bit */
_sfrbit ADC_3IC_IR;                     /* ADC_3IC.7: Interrupt Request Flag */
_sfrbit ADC_3IC_GPX;                    /* ADC_3IC.8: Group Priority Extension */

_esfr U0C0_0IC;                         /* USIC0 Channel 0 IC 0 */
_esfrbit U0C0_0IC_IE;                   /* U0C0_0IC.6: Interrupt Enable Control Bit */
_esfrbit U0C0_0IC_IR;                   /* U0C0_0IC.7: Interrupt Request Flag */
_esfrbit U0C0_0IC_GPX;                  /* U0C0_0IC.8: Group Priority Extension */

_esfr U0C0_1IC;                         /* USIC0 Channel 0 IC 1 */
_esfrbit U0C0_1IC_IE;                   /* U0C0_1IC.6: Interrupt Enable Control Bit */
_esfrbit U0C0_1IC_IR;                   /* U0C0_1IC.7: Interrupt Request Flag */
_esfrbit U0C0_1IC_GPX;                  /* U0C0_1IC.8: Group Priority Extension */

_esfr U0C0_2IC;                         /* USIC0 Channel 0 IC 2 */
_esfrbit U0C0_2IC_IE;                   /* U0C0_2IC.6: Interrupt Enable Control Bit */
_esfrbit U0C0_2IC_IR;                   /* U0C0_2IC.7: Interrupt Request Flag */
_esfrbit U0C0_2IC_GPX;                  /* U0C0_2IC.8: Group Priority Extension */

_esfr U0C1_0IC;                         /* USIC0 Channel 1 IC 0 */
_esfrbit U0C1_0IC_IE;                   /* U0C1_0IC.6: Interrupt Enable Control Bit */
_esfrbit U0C1_0IC_IR;                   /* U0C1_0IC.7: Interrupt Request Flag */
_esfrbit U0C1_0IC_GPX;                  /* U0C1_0IC.8: Group Priority Extension */

_esfr U0C1_1IC;                         /* USIC0 Channel 1 IC 1 */
_esfrbit U0C1_1IC_IE;                   /* U0C1_1IC.6: Interrupt Enable Control Bit */
_esfrbit U0C1_1IC_IR;                   /* U0C1_1IC.7: Interrupt Request Flag */
_esfrbit U0C1_1IC_GPX;                  /* U0C1_1IC.8: Group Priority Extension */

_esfr U0C1_2IC;                         /* USIC0 Channel 1 IC 2 */
_esfrbit U0C1_2IC_IE;                   /* U0C1_2IC.6: Interrupt Enable Control Bit */
_esfrbit U0C1_2IC_IR;                   /* U0C1_2IC.7: Interrupt Request Flag */
_esfrbit U0C1_2IC_GPX;                  /* U0C1_2IC.8: Group Priority Extension */

_esfr CCU60_0IC;                        /* CCU60 Interrupt Control 0 */
_esfrbit CCU60_0IC_IE;                  /* CCU60_0IC.6: Interrupt Enable Control Bit */
_esfrbit CCU60_0IC_IR;                  /* CCU60_0IC.7: Interrupt Request Flag */
_esfrbit CCU60_0IC_GPX;                 /* CCU60_0IC.8: Group Priority Extension */

_esfr CCU60_1IC;                        /* CCU60 Interrupt Control 1 */
_esfrbit CCU60_1IC_IE;                  /* CCU60_1IC.6: Interrupt Enable Control Bit */
_esfrbit CCU60_1IC_IR;                  /* CCU60_1IC.7: Interrupt Request Flag */
_esfrbit CCU60_1IC_GPX;                 /* CCU60_1IC.8: Group Priority Extension */

_esfr CCU60_2IC;                        /* CCU60 Interrupt Control 2 */
_esfrbit CCU60_2IC_IE;                  /* CCU60_2IC.6: Interrupt Enable Control Bit */
_esfrbit CCU60_2IC_IR;                  /* CCU60_2IC.7: Interrupt Request Flag */
_esfrbit CCU60_2IC_GPX;                 /* CCU60_2IC.8: Group Priority Extension */

_esfr CCU60_3IC;                        /* CCU60 Interrupt Control 3 */
_esfrbit CCU60_3IC_IE;                  /* CCU60_3IC.6: Interrupt Enable Control Bit */
_esfrbit CCU60_3IC_IR;                  /* CCU60_3IC.7: Interrupt Request Flag */
_esfrbit CCU60_3IC_GPX;                 /* CCU60_3IC.8: Group Priority Extension */

_sfr GPT12E_T2IC;                       /* GPT12 TIMER 2 IC */
_sfrbit GPT12E_T2IC_IE;                 /* GPT12E_T2IC.6: <GPT12E_T2IC_IE> */
_sfrbit GPT12E_T2IC_IR;                 /* GPT12E_T2IC.7: <GPT12E_T2IC_IR> */
_sfrbit GPT12E_T2IC_GPX;                /* GPT12E_T2IC.8: <GPT12E_T2IC_GPX> */

#define T2IC            GPT12E_T2IC

_sfr GPT12E_T3IC;                       /* GPT12 TIMER 3 IC */
_sfrbit GPT12E_T3IC_IE;                 /* GPT12E_T3IC.6: <GPT12E_T3IC_IE> */
_sfrbit GPT12E_T3IC_IR;                 /* GPT12E_T3IC.7: <GPT12E_T3IC_IR> */
_sfrbit GPT12E_T3IC_GPX;                /* GPT12E_T3IC.8: <GPT12E_T3IC_GPX> */

#define T3IC            GPT12E_T3IC

_sfr GPT12E_T4IC;                       /* GPT12 TIMER 4 IC */
_sfrbit GPT12E_T4IC_IE;                 /* GPT12E_T4IC.6: <GPT12E_T4IC_IE> */
_sfrbit GPT12E_T4IC_IR;                 /* GPT12E_T4IC.7: <GPT12E_T4IC_IR> */
_sfrbit GPT12E_T4IC_GPX;                /* GPT12E_T4IC.8: <GPT12E_T4IC_GPX> */

#define T4IC            GPT12E_T4IC

_sfr GPT12E_T5IC;                       /* GPT12 TIMER 5 IC */
_sfrbit GPT12E_T5IC_IE;                 /* GPT12E_T5IC.6: <GPT12E_T5IC_IE> */
_sfrbit GPT12E_T5IC_IR;                 /* GPT12E_T5IC.7: <GPT12E_T5IC_IR> */
_sfrbit GPT12E_T5IC_GPX;                /* GPT12E_T5IC.8: <GPT12E_T5IC_GPX> */

#define T5IC            GPT12E_T5IC

_sfr GPT12E_T6IC;                       /* GPT12 TIMER 6 IC */
_sfrbit GPT12E_T6IC_IE;                 /* GPT12E_T6IC.6: <GPT12E_T6IC_IE> */
_sfrbit GPT12E_T6IC_IR;                 /* GPT12E_T6IC.7: <GPT12E_T6IC_IR> */
_sfrbit GPT12E_T6IC_GPX;                /* GPT12E_T6IC.8: <GPT12E_T6IC_GPX> */

#define T6IC            GPT12E_T6IC

_sfr GPT12E_CRIC;                       /* GPT12 CAPREL IC */
_sfrbit GPT12E_CRIC_IE;                 /* GPT12E_CRIC.6: <GPT12E_CRIC_IE> */
_sfrbit GPT12E_CRIC_IR;                 /* GPT12E_CRIC.7: <GPT12E_CRIC_IR> */
_sfrbit GPT12E_CRIC_GPX;                /* GPT12E_CRIC.8: <GPT12E_CRIC_GPX> */

#define CRIC            GPT12E_CRIC

_sfr CC2_T7IC;                          /* CAPCOM TIMER 7 IC */
_sfrbit CC2_T7IC_IE;                    /* CC2_T7IC.6: <CC2_T7IC_IE> */
_sfrbit CC2_T7IC_IR;                    /* CC2_T7IC.7: <CC2_T7IC_IR> */
_sfrbit CC2_T7IC_GPX;                   /* CC2_T7IC.8: <CC2_T7IC_GPX> */

#define T7IC            CC2_T7IC

_sfr CC2_T8IC;                          /* CAPCOM TIMER 8 IC */
_sfrbit CC2_T8IC_IE;                    /* CC2_T8IC.6: <CC2_T8IC_IE> */
_sfrbit CC2_T8IC_IR;                    /* CC2_T8IC.7: <CC2_T8IC_IR> */
_sfrbit CC2_T8IC_GPX;                   /* CC2_T8IC.8: <CC2_T8IC_GPX> */

#define T8IC            CC2_T8IC

_esfr CC2_CC16IC;                       /* CAPCOM Interrupt Control 16 */
_esfrbit CC2_CC16IC_IE;                 /* CC2_CC16IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC16IC_IR;                 /* CC2_CC16IC.7: Interrupt Request Flag */
_esfrbit CC2_CC16IC_GPX;                /* CC2_CC16IC.8: Group Priority Extension */

_esfr CC2_CC17IC;                       /* CAPCOM Interrupt Control 17 */
_esfrbit CC2_CC17IC_IE;                 /* CC2_CC17IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC17IC_IR;                 /* CC2_CC17IC.7: Interrupt Request Flag */
_esfrbit CC2_CC17IC_GPX;                /* CC2_CC17IC.8: Group Priority Extension */

_esfr CC2_CC18IC;                       /* CAPCOM Interrupt Control 18 */
_esfrbit CC2_CC18IC_IE;                 /* CC2_CC18IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC18IC_IR;                 /* CC2_CC18IC.7: Interrupt Request Flag */
_esfrbit CC2_CC18IC_GPX;                /* CC2_CC18IC.8: Group Priority Extension */

_esfr CC2_CC19IC;                       /* CAPCOM Interrupt Control 19 */
_esfrbit CC2_CC19IC_IE;                 /* CC2_CC19IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC19IC_IR;                 /* CC2_CC19IC.7: Interrupt Request Flag */
_esfrbit CC2_CC19IC_GPX;                /* CC2_CC19IC.8: Group Priority Extension */

_esfr CC2_CC20IC;                       /* CAPCOM Interrupt Control 20 */
_esfrbit CC2_CC20IC_IE;                 /* CC2_CC20IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC20IC_IR;                 /* CC2_CC20IC.7: Interrupt Request Flag */
_esfrbit CC2_CC20IC_GPX;                /* CC2_CC20IC.8: Group Priority Extension */

_esfr CC2_CC21IC;                       /* CAPCOM Interrupt Control 21 */
_esfrbit CC2_CC21IC_IE;                 /* CC2_CC21IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC21IC_IR;                 /* CC2_CC21IC.7: Interrupt Request Flag */
_esfrbit CC2_CC21IC_GPX;                /* CC2_CC21IC.8: Group Priority Extension */

_esfr CC2_CC22IC;                       /* CAPCOM Interrupt Control 22 */
_esfrbit CC2_CC22IC_IE;                 /* CC2_CC22IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC22IC_IR;                 /* CC2_CC22IC.7: Interrupt Request Flag */
_esfrbit CC2_CC22IC_GPX;                /* CC2_CC22IC.8: Group Priority Extension */

_esfr CC2_CC23IC;                       /* CAPCOM Interrupt Control 23 */
_esfrbit CC2_CC23IC_IE;                 /* CC2_CC23IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC23IC_IR;                 /* CC2_CC23IC.7: Interrupt Request Flag */
_esfrbit CC2_CC23IC_GPX;                /* CC2_CC23IC.8: Group Priority Extension */

_esfr CC2_CC24IC;                       /* CAPCOM Interrupt Control 24 */
_esfrbit CC2_CC24IC_IE;                 /* CC2_CC24IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC24IC_IR;                 /* CC2_CC24IC.7: Interrupt Request Flag */
_esfrbit CC2_CC24IC_GPX;                /* CC2_CC24IC.8: Group Priority Extension */

_esfr CC2_CC25IC;                       /* CAPCOM Interrupt Control 25 */
_esfrbit CC2_CC25IC_IE;                 /* CC2_CC25IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC25IC_IR;                 /* CC2_CC25IC.7: Interrupt Request Flag */
_esfrbit CC2_CC25IC_GPX;                /* CC2_CC25IC.8: Group Priority Extension */

_esfr CC2_CC26IC;                       /* CAPCOM Interrupt Control 26 */
_esfrbit CC2_CC26IC_IE;                 /* CC2_CC26IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC26IC_IR;                 /* CC2_CC26IC.7: Interrupt Request Flag */
_esfrbit CC2_CC26IC_GPX;                /* CC2_CC26IC.8: Group Priority Extension */

_esfr CC2_CC27IC;                       /* CAPCOM Interrupt Control 27 */
_esfrbit CC2_CC27IC_IE;                 /* CC2_CC27IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC27IC_IR;                 /* CC2_CC27IC.7: Interrupt Request Flag */
_esfrbit CC2_CC27IC_GPX;                /* CC2_CC27IC.8: Group Priority Extension */

_esfr CC2_CC28IC;                       /* CAPCOM Interrupt Control 28 */
_esfrbit CC2_CC28IC_IE;                 /* CC2_CC28IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC28IC_IR;                 /* CC2_CC28IC.7: Interrupt Request Flag */
_esfrbit CC2_CC28IC_GPX;                /* CC2_CC28IC.8: Group Priority Extension */

_esfr CC2_CC29IC;                       /* CAPCOM Interrupt Control 29 */
_esfrbit CC2_CC29IC_IE;                 /* CC2_CC29IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC29IC_IR;                 /* CC2_CC29IC.7: Interrupt Request Flag */
_esfrbit CC2_CC29IC_GPX;                /* CC2_CC29IC.8: Group Priority Extension */

_esfr CC2_CC30IC;                       /* CAPCOM Interrupt Control 30 */
_esfrbit CC2_CC30IC_IE;                 /* CC2_CC30IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC30IC_IR;                 /* CC2_CC30IC.7: Interrupt Request Flag */
_esfrbit CC2_CC30IC_GPX;                /* CC2_CC30IC.8: Group Priority Extension */

_esfr CC2_CC31IC;                       /* CAPCOM Interrupt Control 31 */
_esfrbit CC2_CC31IC_IE;                 /* CC2_CC31IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC31IC_IR;                 /* CC2_CC31IC.7: Interrupt Request Flag */
_esfrbit CC2_CC31IC_GPX;                /* CC2_CC31IC.8: Group Priority Extension */

_esfr RTC_IC;                           /* Real Time Clock IC */
_esfrbit RTC_IC_IE;                     /* RTC_IC.6: Interrupt Enable Control Bit */
_esfrbit RTC_IC_IR;                     /* RTC_IC.7: Interrupt Request Flag */
_esfrbit RTC_IC_GPX;                    /* RTC_IC.8: Group Priority Extension */

_esfr ERU_0IC;                          /* External Request Unit 0 IC */
_esfrbit ERU_0IC_IE;                    /* ERU_0IC.6: Interrupt Enable Control Bit */
_esfrbit ERU_0IC_IR;                    /* ERU_0IC.7: Interrupt Request Flag */
_esfrbit ERU_0IC_GPX;                   /* ERU_0IC.8: Group Priority Extension */

_esfr ERU_1IC;                          /* External Request Unit 2 IC */
_esfrbit ERU_1IC_IE;                    /* ERU_1IC.6: Interrupt Enable Control Bit */
_esfrbit ERU_1IC_IR;                    /* ERU_1IC.7: Interrupt Request Flag */
_esfrbit ERU_1IC_GPX;                   /* ERU_1IC.8: Group Priority Extension */

_esfr ERU_2IC;                          /* External Request Unit 2 IC */
_esfrbit ERU_2IC_IE;                    /* ERU_2IC.6: Interrupt Enable Control Bit */
_esfrbit ERU_2IC_IR;                    /* ERU_2IC.7: Interrupt Request Flag */
_esfrbit ERU_2IC_GPX;                   /* ERU_2IC.8: Group Priority Extension */

_esfr ERU_3IC;                          /* External Request Unit 3 IC */
_esfrbit ERU_3IC_IE;                    /* ERU_3IC.6: Interrupt Enable Control Bit */
_esfrbit ERU_3IC_IR;                    /* ERU_3IC.7: Interrupt Request Flag */
_esfrbit ERU_3IC_GPX;                   /* ERU_3IC.8: Group Priority Extension */

_esfr SCU_0IC;                          /* SCU Interrupt 0 IC */
_esfrbit SCU_0IC_IE;                    /* SCU_0IC.6: Interrupt Enable Control Bit */
_esfrbit SCU_0IC_IR;                    /* SCU_0IC.7: Interrupt Request Flag */
_esfrbit SCU_0IC_GPX;                   /* SCU_0IC.8: Group Priority Extension */

_esfr SCU_1IC;                          /* SCU Interrupt 1 IC */
_esfrbit SCU_1IC_IE;                    /* SCU_1IC.6: Interrupt Enable Control Bit */
_esfrbit SCU_1IC_IR;                    /* SCU_1IC.7: Interrupt Request Flag */
_esfrbit SCU_1IC_GPX;                   /* SCU_1IC.8: Group Priority Extension */

#endif /* REGXC2310S_NOINTERRUPT */

/********************************************************************************
 * System Control Unit
********************************************************************************/
#ifndef REGXC2310S_NOSCU

_esfr SCU_WUOSCCON;                     /* Wake-up OSC Control Register */
_esfrbit SCU_WUOSCCON_DIS;              /* SCU_WUOSCCON.4: Clock Disable */

_esfr SCU_HPOSCCON;                     /* High Precision OSC Control Register */
_esfrbit SCU_HPOSCCON_PLLV;             /* SCU_HPOSCCON.0: Oscillator for PLL Valid Status Bit */
_esfrbit SCU_HPOSCCON_OSCWDTRST;        /* SCU_HPOSCCON.1: Oscillator Watchdog Reset */
_esfrbit SCU_HPOSCCON_X1D;              /* SCU_HPOSCCON.6: XTAL1 Data Value */
_esfrbit SCU_HPOSCCON_X1DEN;            /* SCU_HPOSCCON.7: XTAL1 Data Enable */
_esfrbit SCU_HPOSCCON_SHBY;             /* SCU_HPOSCCON.8: Shaper Bypass */
_esfrbit SCU_HPOSCCON_EMCLKEN;          /* SCU_HPOSCCON.9: OSCWDT Emergency System Clock Source Select Enable */
_esfrbit SCU_HPOSCCON_EMFINDISEN;       /* SCU_HPOSCCON.10: Emergency Input Clock Disconnect Enable */
_esfrbit SCU_HPOSCCON_OSC2L1;           /* SCU_HPOSCCON.11: OSC_HP Not Usable Frequency Event */
_esfrbit SCU_HPOSCCON_OSC2L0;           /* SCU_HPOSCCON.12: OSC_HP Usable Frequency Event */

_esfr SCU_PLLOSCCON;                    /* PLL OSC Control Register */
_esfrbit SCU_PLLOSCCON_OSCPD;           /* SCU_PLLOSCCON.0: Clock Source Power Saving Mode */

_esfr SCU_PLLSTAT;                      /* PLL Status Register */

_esfr SCU_STATCLR1;                     /* PLL Status Clear 1 Register */

_esfr SCU_PLLCON0;                      /* PLL Configuration 0 Register */
_esfrbit SCU_PLLCON0_VCOBY;             /* SCU_PLLCON0.0: VCO Bypass */
_esfrbit SCU_PLLCON0_VCOPWD;            /* SCU_PLLCON0.1: VCO Power Saving Mode */
_esfrbit SCU_PLLCON0_REGENCLR;          /* SCU_PLLCON0.4: Power Regulator Enable Clear */
_esfrbit SCU_PLLCON0_REGENSET;          /* SCU_PLLCON0.5: Power Regulator Enable Set */
_esfrbit SCU_PLLCON0_INSEL;             /* SCU_PLLCON0.6: Input Select */
_esfrbit SCU_PLLCON0_NACK;              /* SCU_PLLCON0.15: N-Divider Ready Acknowledge */

_esfr SCU_PLLCON1;                      /* PLL Configuration 1 Register */
_esfrbit SCU_PLLCON1_PLLPWD;            /* SCU_PLLCON1.0: PLL Power Saving Mode */
_esfrbit SCU_PLLCON1_OSCSEL;            /* SCU_PLLCON1.1: Oscillator Input Selection */
_esfrbit SCU_PLLCON1_RESLD;             /* SCU_PLLCON1.2: Restart VCO Lock Detection */
_esfrbit SCU_PLLCON1_AOSCSEL;           /* SCU_PLLCON1.3: Asynchronous Oscillator Input Selection */
_esfrbit SCU_PLLCON1_EMCLKEN;           /* SCU_PLLCON1.5: VCOLCK Emergency System Clock Source Select Enable */
_esfrbit SCU_PLLCON1_EMFINDISEN;        /* SCU_PLLCON1.6: Emergency Input Clock Disconnect Enable */
_esfrbit SCU_PLLCON1_PACK;              /* SCU_PLLCON1.15: P-Divider Ready Acknowledge */

_esfr SCU_PLLCON2;                      /* PLL Configuration 2 Register */
_esfrbit SCU_PLLCON2_K1ACK;             /* SCU_PLLCON2.15: K1-Divider Ready AcknowledgePlease refer to the Programmer’s Guide for a description of the proper handling. */

_esfr SCU_PLLCON3;                      /* PLL Configuration 3 Register */
_esfrbit SCU_PLLCON3_K2ACK;             /* SCU_PLLCON3.15: K2-Divider Ready AcknowledgePlease refer to the Programmer’s Guide for a description of the proper handling. */

_sfr SCU_SYSCON0;                       /* System Control 0 Register */
_sfrbit SCU_SYSCON0_EMCLKSELEN;         /* SCU_SYSCON0.6: Emergency Clock Select Enable */
_sfrbit SCU_SYSCON0_EMSOSC;             /* SCU_SYSCON0.12: OSCWDT Emergency Event Source Status */
_sfrbit SCU_SYSCON0_EMSVCO;             /* SCU_SYSCON0.13: VCOLCK Emergency Event Source Status */
_sfrbit SCU_SYSCON0_SELSTAT;            /* SCU_SYSCON0.15: Clock Select Status */

#define SYSCON0         SCU_SYSCON0

_esfr SCU_STATCLR0;                     /* Status Clear 0 Register */

_sfr SCU_RTCCLKCON;                     /* RTC Clock Control Register */
_sfrbit SCU_RTCCLKCON_RTCCM;            /* SCU_RTCCLKCON.2: RTC Clocking Mode */

_sfr SCU_EXTCON;                        /* External Clock Control Register */
_sfrbit SCU_EXTCON_EN;                  /* SCU_EXTCON.0: External Clock Enable */
_sfrbit SCU_EXTCON_FOTL;                /* SCU_EXTCON.6: Frequency Output Toggle Latch */
_sfrbit SCU_EXTCON_FOSS;                /* SCU_EXTCON.14: Frequency Output Signal Select */
_sfrbit SCU_EXTCON_FOEN;                /* SCU_EXTCON.15: Frequency Output Enable */

_esfr SCU_STMREL;                       /* STM Reload Register */

_esfr SCU_STMCON;                       /* STM Control Register */
_esfrbit SCU_STMCON_RUN;                /* SCU_STMCON.0: Run Control */

_esfr SCU_WUTREL;                       /* Wake-up Timer Reload Register */

_esfr SCU_WUCR;                         /* Wake-up Control Register */
_esfrbit SCU_WUCR_CLRTRG;               /* SCU_WUCR.7: Clear Bit WUTRG */
_esfrbit SCU_WUCR_RUN;                  /* SCU_WUCR.8: Run Indicator */
_esfrbit SCU_WUCR_AON;                  /* SCU_WUCR.9: Auto-Start Indicator */
_esfrbit SCU_WUCR_ASP;                  /* SCU_WUCR.10: Auto-Stop Indicator */
_esfrbit SCU_WUCR_TTSTAT;               /* SCU_WUCR.14: Trim Trigger Status */
_esfrbit SCU_WUCR_WUTRG;                /* SCU_WUCR.15: WUT Trigger Indicator */

_esfr SCU_RSTSTAT0;                     /* Reset Status 0 Register */

_esfr SCU_RSTSTAT1;                     /* Reset Status 1 Register */

_esfr SCU_RSTSTAT2;                     /* Reset Status 2 Register */

_esfr SCU_RSTCON0;                      /* Reset Configuration 0 Register */

_esfr SCU_RSTCON1;                      /* Reset Configuration 1 Register */

_esfr SCU_RSTCNTCON;                    /* Reset Counter Control Register */

_esfr SCU_SWRSTCON;                     /* Software Reset Control Register */

_sfr SCU_ESREXCON1;                     /* ESR1 External Control Register */
_sfrbit SCU_ESREXCON1_ESREN;            /* SCU_ESREXCON1.0: ESRy Pin Enable */
_sfrbit SCU_ESREXCON1_ESRIN0EN;         /* SCU_ESREXCON1.1: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN1EN;         /* SCU_ESREXCON1.2: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN2EN;         /* SCU_ESREXCON1.3: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN3EN;         /* SCU_ESREXCON1.4: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN4EN;         /* SCU_ESREXCON1.5: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN5EN;         /* SCU_ESREXCON1.6: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN6EN;         /* SCU_ESREXCON1.7: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN7EN;         /* SCU_ESREXCON1.8: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN8EN;         /* SCU_ESREXCON1.9: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN9EN;         /* SCU_ESREXCON1.10: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN10EN;        /* SCU_ESREXCON1.11: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN11EN;        /* SCU_ESREXCON1.12: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN12EN;        /* SCU_ESREXCON1.13: ESR Input 12 Enable */
_sfrbit SCU_ESREXCON1_ESRNIN10EN;       /* SCU_ESREXCON1.14: Negated ESR Input 10 Enable */
_sfrbit SCU_ESREXCON1_ESRNIN11EN;       /* SCU_ESREXCON1.15: Negated ESR Input 11 Enable */

_sfr SCU_ESREXCON2;                     /* ESR2 External Control Register */
_sfrbit SCU_ESREXCON2_ESREN;            /* SCU_ESREXCON2.0: ESRy Pin Enable */
_sfrbit SCU_ESREXCON2_ESRIN0EN;         /* SCU_ESREXCON2.1: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN1EN;         /* SCU_ESREXCON2.2: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN2EN;         /* SCU_ESREXCON2.3: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN3EN;         /* SCU_ESREXCON2.4: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN4EN;         /* SCU_ESREXCON2.5: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN5EN;         /* SCU_ESREXCON2.6: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN6EN;         /* SCU_ESREXCON2.7: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN7EN;         /* SCU_ESREXCON2.8: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN8EN;         /* SCU_ESREXCON2.9: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN9EN;         /* SCU_ESREXCON2.10: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN10EN;        /* SCU_ESREXCON2.11: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN11EN;        /* SCU_ESREXCON2.12: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN12EN;        /* SCU_ESREXCON2.13: ESR Input 12 Enable */
_sfrbit SCU_ESREXCON2_ESRNIN10EN;       /* SCU_ESREXCON2.14: Negated ESR Input 10 Enable */
_sfrbit SCU_ESREXCON2_ESRNIN11EN;       /* SCU_ESREXCON2.15: Negated ESR Input 11 Enable */

_sfr SCU_ESREXSTAT1;                    /* ESR1 External Status Register */
_sfrbit SCU_ESREXSTAT1_ESR;             /* SCU_ESREXSTAT1.0: Input ESRy Status */
_sfrbit SCU_ESREXSTAT1_IN0;             /* SCU_ESREXSTAT1.1: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN1;             /* SCU_ESREXSTAT1.2: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN2;             /* SCU_ESREXSTAT1.3: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN3;             /* SCU_ESREXSTAT1.4: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN4;             /* SCU_ESREXSTAT1.5: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN5;             /* SCU_ESREXSTAT1.6: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN6;             /* SCU_ESREXSTAT1.7: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN7;             /* SCU_ESREXSTAT1.8: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN8;             /* SCU_ESREXSTAT1.9: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN9;             /* SCU_ESREXSTAT1.10: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN10;            /* SCU_ESREXSTAT1.11: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN11;            /* SCU_ESREXSTAT1.12: Input x Status */

_sfr SCU_ESREXSTAT2;                    /* ESR2 External Status Register */
_sfrbit SCU_ESREXSTAT2_ESR;             /* SCU_ESREXSTAT2.0: Input ESRy Status */
_sfrbit SCU_ESREXSTAT2_IN0;             /* SCU_ESREXSTAT2.1: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN1;             /* SCU_ESREXSTAT2.2: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN2;             /* SCU_ESREXSTAT2.3: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN3;             /* SCU_ESREXSTAT2.4: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN4;             /* SCU_ESREXSTAT2.5: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN5;             /* SCU_ESREXSTAT2.6: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN6;             /* SCU_ESREXSTAT2.7: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN7;             /* SCU_ESREXSTAT2.8: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN8;             /* SCU_ESREXSTAT2.9: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN9;             /* SCU_ESREXSTAT2.10: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN10;            /* SCU_ESREXSTAT2.11: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN11;            /* SCU_ESREXSTAT2.12: Input x Status */

_sfr SCU_CLRESREXSTAT1;                 /* Clear ESR1 External Status Register */
_sfrbit SCU_CLRESREXSTAT1_ESR;          /* SCU_CLRESREXSTAT1.0: Clear Input ESRy Status */
_sfrbit SCU_CLRESREXSTAT1_IN0;          /* SCU_CLRESREXSTAT1.1: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN1;          /* SCU_CLRESREXSTAT1.2: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN2;          /* SCU_CLRESREXSTAT1.3: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN3;          /* SCU_CLRESREXSTAT1.4: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN4;          /* SCU_CLRESREXSTAT1.5: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN5;          /* SCU_CLRESREXSTAT1.6: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN6;          /* SCU_CLRESREXSTAT1.7: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN7;          /* SCU_CLRESREXSTAT1.8: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN8;          /* SCU_CLRESREXSTAT1.9: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN9;          /* SCU_CLRESREXSTAT1.10: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN10;         /* SCU_CLRESREXSTAT1.11: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN11;         /* SCU_CLRESREXSTAT1.12: Clear Input x Status */

_sfr SCU_CLRESREXSTAT2;                 /* Clear ESR2 External Status Register */
_sfrbit SCU_CLRESREXSTAT2_ESR;          /* SCU_CLRESREXSTAT2.0: Clear Input ESRy Status */
_sfrbit SCU_CLRESREXSTAT2_IN0;          /* SCU_CLRESREXSTAT2.1: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN1;          /* SCU_CLRESREXSTAT2.2: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN2;          /* SCU_CLRESREXSTAT2.3: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN3;          /* SCU_CLRESREXSTAT2.4: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN4;          /* SCU_CLRESREXSTAT2.5: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN5;          /* SCU_CLRESREXSTAT2.6: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN6;          /* SCU_CLRESREXSTAT2.7: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN7;          /* SCU_CLRESREXSTAT2.8: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN8;          /* SCU_CLRESREXSTAT2.9: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN9;          /* SCU_CLRESREXSTAT2.10: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN10;         /* SCU_CLRESREXSTAT2.11: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN11;         /* SCU_CLRESREXSTAT2.12: Clear Input x Status */

_esfr SCU_ESRCFG1;                      /* ESR1 Configuration Register */
_esfrbit SCU_ESRCFG1_DFEN;              /* SCU_ESRCFG1.4: Digital Filter Enable */
_esfrbit SCU_ESRCFG1_OUT;               /* SCU_ESRCFG1.5: Data Output */
_esfrbit SCU_ESRCFG1_IN;                /* SCU_ESRCFG1.6: Data Input */

_esfr SCU_ESRCFG2;                      /* ESR2 Configuration Register */
_esfrbit SCU_ESRCFG2_DFEN;              /* SCU_ESRCFG2.4: Digital Filter Enable */
_esfrbit SCU_ESRCFG2_OUT;               /* SCU_ESRCFG2.5: Data Output */
_esfrbit SCU_ESRCFG2_IN;                /* SCU_ESRCFG2.6: Data Input */

_esfr SCU_SWDCON0;                      /* SWD Control 0 Register */

_esfr SCU_SWDCON1;                      /* SWD Control 1 Register */

_esfr SCU_PVCMCON0;                     /* PVC_M Control Step 0 Register MEM */

_esfr SCU_EVRMCON0;                     /* EVR_M Control 0 Register */

_esfr SCU_EVRMCON1;                     /* EVR_M Control 1 Register */

_esfr SCU_EVRMSET15VLP;                 /* EVR_M Setting for 1.5V LP Register */

_esfr SCU_EVRMSET15VHP;                 /* EVR_M Setting for 1.5V HP Register */

_sfr SCU_SEQCON;                        /* Sequence Control Register */

_sfr SCU_PSCSTAT;                       /* PSC Status Register */

_sfr SCU_STEP0;                         /* Step 0 Register */

_sfr SCU_SEQASTEP1;                     /* Sequence Step 1 for Set A Register */

_sfr SCU_SEQASTEP2;                     /* Sequence Step 2 for Set A Register */

_sfr SCU_SEQASTEP3;                     /* Sequence Step 3 for Set A Register */

_sfr SCU_SEQASTEP4;                     /* Sequence Step 4 for Set A Register */

_sfr SCU_SEQASTEP5;                     /* Sequence Step 5 for Set A Register */

_sfr SCU_SEQASTEP6;                     /* Sequence Step 6 for Set A Register */

_sfr SCU_SEQBSTEP1;                     /* Sequence Step 1 for Set B Register */

_sfr SCU_SEQBSTEP2;                     /* Sequence Step 2 for Set B Register */

_sfr SCU_SEQBSTEP3;                     /* Sequence Step 3 for Set B Register */

_sfr SCU_SEQBSTEP4;                     /* Sequence Step 4 for Set B Register */

_sfr SCU_SEQBSTEP5;                     /* Sequence Step 5 for Set B Register */

_sfr SCU_SEQBSTEP6;                     /* Sequence Step 6 for Set B Register */

_xsfr SCU_PVCMCONA1;                    /* PVC_M Control for Step 1 Set A Register MEM */

_xsfr SCU_PVCMCONA2;                    /* PVC_M Control for Step 2 Set A Register MEM */

_xsfr SCU_PVCMCONA3;                    /* PVC_M Control for Step 3 Set A Register MEM */

_xsfr SCU_PVCMCONA4;                    /* PVC_M Control for Step 4 Set A Register MEM */

_xsfr SCU_PVCMCONA5;                    /* PVC_M Control for Step 5 Set A Register MEM */

_xsfr SCU_PVCMCONA6;                    /* PVC_M Control for Step 6 Set A Register MEM */

_xsfr SCU_PVCMCONB1;                    /* PVC_M Control for Step 1 Set B Register MEM */

_xsfr SCU_PVCMCONB2;                    /* PVC_M Control for Step 2 Set B Register MEM */

_xsfr SCU_PVCMCONB3;                    /* PVC_M Control for Step 3 Set B Register MEM */

_xsfr SCU_PVCMCONB4;                    /* PVC_M Control for Step 4 Set B Register MEM */

_xsfr SCU_PVCMCONB5;                    /* PVC_M Control for Step 5 Set B Register MEM */

_xsfr SCU_PVCMCONB6;                    /* PVC_M Control for Step 6 Set B Register MEM */

_sfr SCU_GSCSWREQ;                      /* GSC Software Request Register */
_sfrbit SCU_GSCSWREQ_SWTRG1;            /* SCU_GSCSWREQ.0: Software Trigger 1 (SW1) */
_sfrbit SCU_GSCSWREQ_SWTRG2;            /* SCU_GSCSWREQ.1: Software Trigger 2 (SW2) */

_sfr SCU_GSCEN;                         /* GSC Enable Register */
_sfrbit SCU_GSCEN_PSCBEXEN;             /* SCU_GSCEN.0: Reserved */
_sfrbit SCU_GSCEN_PSCBENEN;             /* SCU_GSCEN.1: Reserved */
_sfrbit SCU_GSCEN_PSCAEXEN;             /* SCU_GSCEN.2: Reserved */
_sfrbit SCU_GSCEN_PSCAENEN;             /* SCU_GSCEN.3: Reserved */
_sfrbit SCU_GSCEN_OCDSEXEN;             /* SCU_GSCEN.4: OCDS Exit Request Trigger Enable */
_sfrbit SCU_GSCEN_ESR0EN;               /* SCU_GSCEN.5: Reserved */
_sfrbit SCU_GSCEN_ESR1EN;               /* SCU_GSCEN.6: ESR1 Request Trigger Enable */
_sfrbit SCU_GSCEN_ESR2EN;               /* SCU_GSCEN.7: ESR2 Request Trigger Enable */
_sfrbit SCU_GSCEN_WUTEN;                /* SCU_GSCEN.8: WUT Request Trigger Enable */
_sfrbit SCU_GSCEN_ITCEN;                /* SCU_GSCEN.9: ITC Request Trigger Enable */
_sfrbit SCU_GSCEN_GPTEN;                /* SCU_GSCEN.10: GTP12E Request Trigger Enable */
_sfrbit SCU_GSCEN_SW1EN;                /* SCU_GSCEN.11: Software 1 Request Trigger Enable */
_sfrbit SCU_GSCEN_SW2EN;                /* SCU_GSCEN.12: Software 2 Request Trigger Enable */
_sfrbit SCU_GSCEN_OCDSENEN;             /* SCU_GSCEN.14: OCDS Entry Request Trigger Enable */

_sfr SCU_GSCSTAT;                       /* GSC Status Register */
_sfrbit SCU_GSCSTAT_ERR;                /* SCU_GSCSTAT.8: Error Status Flag */
_sfrbit SCU_GSCSTAT_PEN;                /* SCU_GSCSTAT.9: Command Pending Flag */

_sfr SCU_GSCPERSTATEN;                  /* GSC Peripheral Status Enable Register */
_sfrbit SCU_GSCPERSTATEN_ADC;           /* SCU_GSCPERSTATEN.0: ADC Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_GPT12E;        /* SCU_GSCPERSTATEN.1: GPT12E Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_CC2;           /* SCU_GSCPERSTATEN.3: CC2 Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_CCU60;         /* SCU_GSCPERSTATEN.5: CCU60 Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_RTC;           /* SCU_GSCPERSTATEN.9: RTC Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_MEM;           /* SCU_GSCPERSTATEN.10: C166SV2 Subsystem Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_FL;            /* SCU_GSCPERSTATEN.11: Flash Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_USIC0;         /* SCU_GSCPERSTATEN.12: USIC0 Acknowledge Enable */

_sfr SCU_GSCPERSTAT;                    /* GSC Peripheral Status Register */
_sfrbit SCU_GSCPERSTAT_ADC;             /* SCU_GSCPERSTAT.0: ADC Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_GPT12E;          /* SCU_GSCPERSTAT.1: GPT12E Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_CC2;             /* SCU_GSCPERSTAT.3: CC2 Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_CCU60;           /* SCU_GSCPERSTAT.5: CCU60 Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_RTC;             /* SCU_GSCPERSTAT.9: RTC Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_MEM;             /* SCU_GSCPERSTAT.10: C166SV2 Subsystem Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_FL;              /* SCU_GSCPERSTAT.11: Flash Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_USIC0;           /* SCU_GSCPERSTAT.12: USIC0 Acknowledge Status */

_xsfr SCU_STSTAT;                       /* Start-up Status Register */

_esfr SCU_EXISEL;                       /* External Input Select Register */

#define EXISEL          SCU_EXISEL

_esfr SCU_EXICON0;                      /* External Input Control 0 Register */

_esfr SCU_EXICON1;                      /* External Input Control 1 Register */

_esfr SCU_EXICON2;                      /* External Input Control 2 Register */

_esfr SCU_EXICON3;                      /* External Input Control 3 Register */

_sfr SCU_EXOCON0;                       /* External Output Trigger Control 0 Register */

_sfr SCU_EXOCON1;                       /* External Output Trigger Control 1 Register */

_sfr SCU_EXOCON2;                       /* External Output Trigger Control 2 Register */

_sfr SCU_EXOCON3;                       /* External Output Trigger Control 3 Register */

_sfr SCU_INTSTAT;                       /* Interrupt Status Register */
_sfrbit SCU_INTSTAT_SWDI1;              /* SCU_INTSTAT.0: SWD Interrupt Request Flag 1 */
_sfrbit SCU_INTSTAT_SWDI2;              /* SCU_INTSTAT.1: SWD Interrupt Request Flag 2 */
_sfrbit SCU_INTSTAT_PVCMI1;             /* SCU_INTSTAT.2: PVC_M Interrupt Request Flag 1 */
_sfrbit SCU_INTSTAT_PVCMI2;             /* SCU_INTSTAT.3: PVC_M Interrupt Request Flag 2 */
_sfrbit SCU_INTSTAT_WUTI;               /* SCU_INTSTAT.6: Wake-up Timer Trim Interrupt Request Flag */
_sfrbit SCU_INTSTAT_WUI;                /* SCU_INTSTAT.7: Wake-up Timer Interrupt Request Flag */
_sfrbit SCU_INTSTAT_GSCI;               /* SCU_INTSTAT.9: GSC Interrupt Request Flag */
_sfrbit SCU_INTSTAT_STM0I;              /* SCU_INTSTAT.10: STM Interrupt 0 Request Flag */
_sfrbit SCU_INTSTAT_STM1I;              /* SCU_INTSTAT.11: STM Interrupt 1 Request Flag */
_sfrbit SCU_INTSTAT_MCHKI;              /* SCU_INTSTAT.12: MCHK Interrupt Request Flag */
_sfrbit SCU_INTSTAT_PFI;                /* SCU_INTSTAT.13: Program Flash Interrupt Request Flag */

_sfr SCU_INTCLR;                        /* Interrupt Clear Register */

_sfr SCU_INTSET;                        /* Interrupt Set Register */

_sfr SCU_INTDIS;                        /* Interrupt Disable Register */

_sfr SCU_INTNP0;                        /* Interrupt Node Pointer 0 Register */

_sfr SCU_INTNP1;                        /* Interrupt Node Pointer 1 Register */

_sfr SCU_DMPMIT;                        /* DMP_M Interrupt and Trap Trigger Register */

_sfr SCU_DMPMITCLR;                     /* DMP_M Interrupt and Trap Clear Register */

_esfr SCU_WDTREL;                       /* WDT Reload Register */

#define WDTREL          SCU_WDTREL

_esfr SCU_WDTCS;                        /* WDT Control and Status Register */

#define WDTCS           SCU_WDTCS

_esfr SCU_WDTTIM;                       /* WWD Timer Register */

_esfr SCU_WDTWINB;                      /* WWD Window Boundary Count Register */

_sfr SCU_TRAPSTAT;                      /* Trap Status Register */
_sfrbit SCU_TRAPSTAT_FAT;               /* SCU_TRAPSTAT.0: Flash Access Trap Request Flag */
_sfrbit SCU_TRAPSTAT_ESR1T;             /* SCU_TRAPSTAT.2: ESR1 Trap Request Flag */
_sfrbit SCU_TRAPSTAT_ESR2T;             /* SCU_TRAPSTAT.3: ESR2 Trap Request Flag */
_sfrbit SCU_TRAPSTAT_OSCWDTT;           /* SCU_TRAPSTAT.4: OSCWDT Trap Request Flag */
_sfrbit SCU_TRAPSTAT_RAT;               /* SCU_TRAPSTAT.5: Register Access Trap Request Flag */
_sfrbit SCU_TRAPSTAT_PET;               /* SCU_TRAPSTAT.6: Parity Error Trap Request Flag */
_sfrbit SCU_TRAPSTAT_VCOLCKT;           /* SCU_TRAPSTAT.7: VCOLCK Trap Request Flag */

_sfr SCU_TRAPCLR;                       /* Trap Clear Register */

_sfr SCU_TRAPSET;                       /* Trap Set Register */

_sfr SCU_TRAPDIS;                       /* Trap Disable Register */

_sfr SCU_TRAPNP;                        /* Trap Node Pointer Register */

_esfr SCU_PEEN;                         /* Parity Error Enable Register */

_esfr SCU_PECON;                        /* Parity Error Control Register */

_esfr SCU_PMTPR;                        /* Parity Memory Test Pattern Register */

_esfr SCU_PMTSR;                        /* Parity Memory Test Select Register */

_esfr SCU_SLC;                          /* Security Level Command Register */

#define SLC             SCU_SLC

_esfr SCU_SLS;                          /* Security Level Status Register */

_sfr SCU_SYSCON1;                       /* System Control 1 Register */
_sfrbit SCU_SYSCON1_OCDSEN;             /* SCU_SYSCON1.2: OCDS/Cerberus Enable */
_sfrbit SCU_SYSCON1_GLCCST;             /* SCU_SYSCON1.3: Global CAPCOM Start */

#define SYSCON1         SCU_SYSCON1

_esfr SCU_IDMANUF;                      /* Manufacturer Identification Register */

_esfr SCU_IDCHIP;                       /* Chip Identification Register */

_esfr SCU_IDMEM;                        /* Program Memory Identification Register */

_esfr SCU_IDPROG;                       /* Programming Voltage Id. Register */

_sfr SCU_IDDMPM;                        /* DMP_M Module Identification Register */

_sfr SCU_MKMEM0;                        /* Marker Memory 0 Register */

_sfr SCU_MKMEM1;                        /* Marker Memory 1 Register */

#endif /* REGXC2310S_NOSCU */

/********************************************************************************
 * System Control Unit
********************************************************************************/
#ifndef REGXC2310S_NOSCU

_esfr MEM_KSCCFG;                       /* Memory Subsystem KSCCFG */

_sfr FL_KSCCFG;                         /* Flash Kernel State Con. */


#define IMB_IMBCTRL     (*(_PAGE_3FF_MEM_TYPE(0xFFFF00))) /* IMB Control Low */

#define IMBCTRL         IMB_IMBCTRL

#define IMB_IMBCTRH     (*(_PAGE_3FF_MEM_TYPE(0xFFFF02))) /* IMB Control High */

#define IMBCTRH         IMB_IMBCTRH

#define IMB_INTCTR      (*(_PAGE_3FF_MEM_TYPE(0xFFFF04))) /* Interrupt Control */


#define IMB_FSR_BUSY    (*(_PAGE_3FF_MEM_TYPE(0xFFFF06))) /* Flash State Busy */


#define IMB_FSR_OP      (*(_PAGE_3FF_MEM_TYPE(0xFFFF08))) /* Flash State Operations */


#define IMB_FSR_PROT    (*(_PAGE_3FF_MEM_TYPE(0xFFFF0A))) /* Flash State Protection */


#define IMB_MAR0        (*(_PAGE_3FF_MEM_TYPE(0xFFFF0C))) /* Margin Control 0 */


#define IMB_PROCON0     (*(_PAGE_3FF_MEM_TYPE(0xFFFF10))) /* Protection Configuration 0 */


#define IMB_ECC_TRAP    (*(_PAGE_3FF_MEM_TYPE(0xFFFF20))) /* ECC Trap Control */


#define IMB_ECC_STAT    (*(_PAGE_3FF_MEM_TYPE(0xFFFF22))) /* ECC Status */

#endif /* REGXC2310S_NOSCU */

/********************************************************************************
 * On-Chip Debugging Interface Control Registers
********************************************************************************/
#ifndef REGXC2310S_NOOCDS

_esfr DBGPRR;                           /* Debug Pin Routing Register */

_esfr DEXEVT;                           /* Break Pin Event Control */

_esfr DSWEVT;                           /* Software Debug Event Control Register */

_esfr DTREVT;                           /* Hardware Trigger Event Control Register */

_esfr DBGSR;                            /* Debug Status Register */

_esfr DTIDR;                            /* Task ID Register */

_esfr CMADR;                            /* Monitor target ADdress register */

_esfr CMCTR;                            /* Monitor Control and Break Level register */

_esfr DCMPSP;                           /* Data Compare Select Programming register */

_esfr DCMPDP;                           /* Data Compare Data Programming register */

_esfr RWDATA;                           /* Data Register in RW Mode */

_esfr COMDATA;                          /* Data Register in Communication Mode */

_esfr IOSR;                             /* Status and Control Register */

#endif /* REGXC2310S_NOOCDS */

/********************************************************************************
 * USIC0
********************************************************************************/
#ifndef REGXC2310S_NOUSIC0


#define U0C0_CCR        (*(_PAGE_081_MEM_TYPE(0x204010))) /* Channel Control Register */


#define U0C0_CCFG       (*(_PAGE_081_MEM_TYPE(0x204018))) /* Channel Configuration Register */


#define U0C0_KSCFG      (*(_PAGE_081_MEM_TYPE(0x20400C))) /* Kernel State Configuration Register */


#define U0C0_INPRL      (*(_PAGE_081_MEM_TYPE(0x204014))) /* Interrupt Node Pointer Register L */


#define U0C0_INPRH      (*(_PAGE_081_MEM_TYPE(0x204016))) /* Interrupt Node Pointer Register H */


#define U0C0_PCRL       (*(_PAGE_081_MEM_TYPE(0x204040))) /* Protocol Control Register L */


#define U0C0_PCRH       (*(_PAGE_081_MEM_TYPE(0x204042))) /* Protocol Control Register H */


#define U0C0_PSR        (*(_PAGE_081_MEM_TYPE(0x204044))) /* Protocol Status Register */


#define U0C0_PSCR       (*(_PAGE_081_MEM_TYPE(0x204048))) /* Protocol Status Clear Register */


#define U0C0_DX0CR      (*(_PAGE_081_MEM_TYPE(0x204020))) /* Input Control Register 0 */


#define U0C0_DX1CR      (*(_PAGE_081_MEM_TYPE(0x204024))) /* Input Control Register 1 */


#define U0C0_DX2CR      (*(_PAGE_081_MEM_TYPE(0x204028))) /* Input Control Register 2 */


#define U0C0_FDRL       (*(_PAGE_081_MEM_TYPE(0x204004))) /* Fractional Divider Register L */


#define U0C0_FDRH       (*(_PAGE_081_MEM_TYPE(0x204006))) /* Fractional Divider Register H */


#define U0C0_BRGL       (*(_PAGE_081_MEM_TYPE(0x20401C))) /* Baud Rate Generator Register L */


#define U0C0_BRGH       (*(_PAGE_081_MEM_TYPE(0x20401E))) /* Baud Rate Generator Register H */


#define U0C0_SCTRL      (*(_PAGE_081_MEM_TYPE(0x204030))) /* Shift Control Register L */


#define U0C0_SCTRH      (*(_PAGE_081_MEM_TYPE(0x204032))) /* Shift Control Register H */


#define U0C0_TCSRL      (*(_PAGE_081_MEM_TYPE(0x20403C))) /* Transmit Control/Status Register L */


#define U0C0_TCSRH      (*(_PAGE_081_MEM_TYPE(0x20403E))) /* Transmit Control/Status Register H */


#define U0C0_FMRL       (*(_PAGE_081_MEM_TYPE(0x204038))) /* Flag Modification Register L */


#define U0C0_FMRH       (*(_PAGE_081_MEM_TYPE(0x20403A))) /* Flag Modification Register H */


#define U0C0_TBUF00     (*(_PAGE_081_MEM_TYPE(0x204080))) /* Transmit Buffer Input Location 00 */


#define U0C0_TBUF01     (*(_PAGE_081_MEM_TYPE(0x204084))) /* Transmit Buffer Input Location 01 */


#define U0C0_TBUF02     (*(_PAGE_081_MEM_TYPE(0x204088))) /* Transmit Buffer Input Location 02 */


#define U0C0_TBUF03     (*(_PAGE_081_MEM_TYPE(0x20408C))) /* Transmit Buffer Input Location 03 */


#define U0C0_TBUF04     (*(_PAGE_081_MEM_TYPE(0x204090))) /* Transmit Buffer Input Location 04 */


#define U0C0_TBUF05     (*(_PAGE_081_MEM_TYPE(0x204094))) /* Transmit Buffer Input Location 05 */


#define U0C0_TBUF06     (*(_PAGE_081_MEM_TYPE(0x204098))) /* Transmit Buffer Input Location 06 */


#define U0C0_TBUF07     (*(_PAGE_081_MEM_TYPE(0x20409C))) /* Transmit Buffer Input Location 07 */


#define U0C0_TBUF08     (*(_PAGE_081_MEM_TYPE(0x2040A0))) /* Transmit Buffer Input Location 08 */


#define U0C0_TBUF09     (*(_PAGE_081_MEM_TYPE(0x2040A4))) /* Transmit Buffer Input Location 09 */


#define U0C0_TBUF10     (*(_PAGE_081_MEM_TYPE(0x2040A8))) /* Transmit Buffer Input Location 10 */


#define U0C0_TBUF11     (*(_PAGE_081_MEM_TYPE(0x2040AC))) /* Transmit Buffer Input Location 11 */


#define U0C0_TBUF12     (*(_PAGE_081_MEM_TYPE(0x2040B0))) /* Transmit Buffer Input Location 12 */


#define U0C0_TBUF13     (*(_PAGE_081_MEM_TYPE(0x2040B4))) /* Transmit Buffer Input Location 13 */


#define U0C0_TBUF14     (*(_PAGE_081_MEM_TYPE(0x2040B8))) /* Transmit Buffer Input Location 14 */


#define U0C0_TBUF15     (*(_PAGE_081_MEM_TYPE(0x2040BC))) /* Transmit Buffer Input Location 15 */


#define U0C0_TBUF16     (*(_PAGE_081_MEM_TYPE(0x2040C0))) /* Transmit Buffer Input Location 16 */


#define U0C0_TBUF17     (*(_PAGE_081_MEM_TYPE(0x2040C4))) /* Transmit Buffer Input Location 17 */


#define U0C0_TBUF18     (*(_PAGE_081_MEM_TYPE(0x2040C8))) /* Transmit Buffer Input Location 18 */


#define U0C0_TBUF19     (*(_PAGE_081_MEM_TYPE(0x2040CC))) /* Transmit Buffer Input Location 19 */


#define U0C0_TBUF20     (*(_PAGE_081_MEM_TYPE(0x2040D0))) /* Transmit Buffer Input Location 20 */


#define U0C0_TBUF21     (*(_PAGE_081_MEM_TYPE(0x2040D4))) /* Transmit Buffer Input Location 21 */


#define U0C0_TBUF22     (*(_PAGE_081_MEM_TYPE(0x2040D8))) /* Transmit Buffer Input Location 22 */


#define U0C0_TBUF23     (*(_PAGE_081_MEM_TYPE(0x2040DC))) /* Transmit Buffer Input Location 23 */


#define U0C0_TBUF24     (*(_PAGE_081_MEM_TYPE(0x2040E0))) /* Transmit Buffer Input Location 24 */


#define U0C0_TBUF25     (*(_PAGE_081_MEM_TYPE(0x2040E4))) /* Transmit Buffer Input Location 25 */


#define U0C0_TBUF26     (*(_PAGE_081_MEM_TYPE(0x2040E8))) /* Transmit Buffer Input Location 26 */


#define U0C0_TBUF27     (*(_PAGE_081_MEM_TYPE(0x2040EC))) /* Transmit Buffer Input Location 27 */


#define U0C0_TBUF28     (*(_PAGE_081_MEM_TYPE(0x2040F0))) /* Transmit Buffer Input Location 28 */


#define U0C0_TBUF29     (*(_PAGE_081_MEM_TYPE(0x2040F4))) /* Transmit Buffer Input Location 29 */


#define U0C0_TBUF30     (*(_PAGE_081_MEM_TYPE(0x2040F8))) /* Transmit Buffer Input Location 30 */


#define U0C0_TBUF31     (*(_PAGE_081_MEM_TYPE(0x2040FC))) /* Transmit Buffer Input Location 31 */


#define U0C0_RBUF0      (*(_PAGE_081_MEM_TYPE(0x204050))) /* Receiver Buffer Register 0 */


#define U0C0_RBUF01SRL  (*(_PAGE_081_MEM_TYPE(0x204060))) /* Receiver Buffer 01 Status Register L */


#define U0C0_RBUF1      (*(_PAGE_081_MEM_TYPE(0x204054))) /* Receiver Buffer Register 1 */


#define U0C0_RBUF01SRH  (*(_PAGE_081_MEM_TYPE(0x204062))) /* Receiver Buffer 01 Status Register H */


#define U0C0_RBUF       (*(_PAGE_081_MEM_TYPE(0x20405C))) /* Receiver Buffer Register */


#define U0C0_RBUFD      (*(_PAGE_081_MEM_TYPE(0x20404C))) /* Receiver Buffer Register for Debugger */


#define U0C0_RBUFSR     (*(_PAGE_081_MEM_TYPE(0x204058))) /* Receiver Buffer Status Register */


#define U0C0_BYP        (*(_PAGE_081_MEM_TYPE(0x204100))) /* Bypass Data Register */


#define U0C0_BYPCRL     (*(_PAGE_081_MEM_TYPE(0x204104))) /* Bypass Control Register L */


#define U0C0_BYPCRH     (*(_PAGE_081_MEM_TYPE(0x204106))) /* Bypass Control Register H */


#define U0C0_TRBSRL     (*(_PAGE_081_MEM_TYPE(0x204118))) /* Transmit/Receive Buffer Status Register L */


#define U0C0_TRBSRH     (*(_PAGE_081_MEM_TYPE(0x20411A))) /* Transmit/Receive Buffer Status Register H */


#define U0C0_TRBSCR     (*(_PAGE_081_MEM_TYPE(0x20411C))) /* Transmit/Receive Buffer Status Clear Register */


#define U0C0_TBCTRL     (*(_PAGE_081_MEM_TYPE(0x204110))) /* Transmitter Buffer Control Register L */


#define U0C0_TBCTRH     (*(_PAGE_081_MEM_TYPE(0x204112))) /* Transmitter Buffer Control Register H */


#define U0C0_RBCTRL     (*(_PAGE_081_MEM_TYPE(0x204114))) /* Receiver Buffer Control Register L */


#define U0C0_RBCTRH     (*(_PAGE_081_MEM_TYPE(0x204116))) /* Receiver Buffer Control Register H */


#define U0C0_IN00       (*(_PAGE_081_MEM_TYPE(0x204180))) /* Transmit FIFO Buffer Input Location 00 */


#define U0C0_IN01       (*(_PAGE_081_MEM_TYPE(0x204184))) /* Transmit FIFO Buffer Input Location 01 */


#define U0C0_IN02       (*(_PAGE_081_MEM_TYPE(0x204188))) /* Transmit FIFO Buffer Input Location 02 */


#define U0C0_IN03       (*(_PAGE_081_MEM_TYPE(0x20418C))) /* Transmit FIFO Buffer Input Location 03 */


#define U0C0_IN04       (*(_PAGE_081_MEM_TYPE(0x204190))) /* Transmit FIFO Buffer Input Location 04 */


#define U0C0_IN05       (*(_PAGE_081_MEM_TYPE(0x204194))) /* Transmit FIFO Buffer Input Location 05 */


#define U0C0_IN06       (*(_PAGE_081_MEM_TYPE(0x204198))) /* Transmit FIFO Buffer Input Location 06 */


#define U0C0_IN07       (*(_PAGE_081_MEM_TYPE(0x20419C))) /* Transmit FIFO Buffer Input Location 07 */


#define U0C0_IN08       (*(_PAGE_081_MEM_TYPE(0x2041A0))) /* Transmit FIFO Buffer Input Location 08 */


#define U0C0_IN09       (*(_PAGE_081_MEM_TYPE(0x2041A4))) /* Transmit FIFO Buffer Input Location 09 */


#define U0C0_IN10       (*(_PAGE_081_MEM_TYPE(0x2041A8))) /* Transmit FIFO Buffer Input Location 10 */


#define U0C0_IN11       (*(_PAGE_081_MEM_TYPE(0x2041AC))) /* Transmit FIFO Buffer Input Location 11 */


#define U0C0_IN12       (*(_PAGE_081_MEM_TYPE(0x2041B0))) /* Transmit FIFO Buffer Input Location 12 */


#define U0C0_IN13       (*(_PAGE_081_MEM_TYPE(0x2041B4))) /* Transmit FIFO Buffer Input Location 13 */


#define U0C0_IN14       (*(_PAGE_081_MEM_TYPE(0x2041B8))) /* Transmit FIFO Buffer Input Location 14 */


#define U0C0_IN15       (*(_PAGE_081_MEM_TYPE(0x2041BC))) /* Transmit FIFO Buffer Input Location 15 */


#define U0C0_IN16       (*(_PAGE_081_MEM_TYPE(0x2041C0))) /* Transmit FIFO Buffer Input Location 16 */


#define U0C0_IN17       (*(_PAGE_081_MEM_TYPE(0x2041C4))) /* Transmit FIFO Buffer Input Location 17 */


#define U0C0_IN18       (*(_PAGE_081_MEM_TYPE(0x2041C8))) /* Transmit FIFO Buffer Input Location 18 */


#define U0C0_IN19       (*(_PAGE_081_MEM_TYPE(0x2041CC))) /* Transmit FIFO Buffer Input Location 19 */


#define U0C0_IN20       (*(_PAGE_081_MEM_TYPE(0x2041D0))) /* Transmit FIFO Buffer Input Location 20 */


#define U0C0_IN21       (*(_PAGE_081_MEM_TYPE(0x2041D4))) /* Transmit FIFO Buffer Input Location 21 */


#define U0C0_IN22       (*(_PAGE_081_MEM_TYPE(0x2041D8))) /* Transmit FIFO Buffer Input Location 22 */


#define U0C0_IN23       (*(_PAGE_081_MEM_TYPE(0x2041DC))) /* Transmit FIFO Buffer Input Location 23 */


#define U0C0_IN24       (*(_PAGE_081_MEM_TYPE(0x2041E0))) /* Transmit FIFO Buffer Input Location 24 */


#define U0C0_IN25       (*(_PAGE_081_MEM_TYPE(0x2041E4))) /* Transmit FIFO Buffer Input Location 25 */


#define U0C0_IN26       (*(_PAGE_081_MEM_TYPE(0x2041E8))) /* Transmit FIFO Buffer Input Location 26 */


#define U0C0_IN27       (*(_PAGE_081_MEM_TYPE(0x2041EC))) /* Transmit FIFO Buffer Input Location 27 */


#define U0C0_IN28       (*(_PAGE_081_MEM_TYPE(0x2041F0))) /* Transmit FIFO Buffer Input Location 28 */


#define U0C0_IN29       (*(_PAGE_081_MEM_TYPE(0x2041F4))) /* Transmit FIFO Buffer Input Location 29 */


#define U0C0_IN30       (*(_PAGE_081_MEM_TYPE(0x2041F8))) /* Transmit FIFO Buffer Input Location 30 */


#define U0C0_IN31       (*(_PAGE_081_MEM_TYPE(0x2041FC))) /* Transmit FIFO Buffer Input Location 31 */


#define U0C0_OUTRL      (*(_PAGE_081_MEM_TYPE(0x204120))) /* Receiver Buffer Output Register L */


#define U0C0_OUTRH      (*(_PAGE_081_MEM_TYPE(0x204122))) /* Receiver Buffer Output Register H */


#define U0C0_OUTDRL     (*(_PAGE_081_MEM_TYPE(0x204124))) /* Receiver Buffer Output Register L for Debugger */


#define U0C0_OUTDRH     (*(_PAGE_081_MEM_TYPE(0x204126))) /* Receiver Buffer Output Register H for Debugger */


#define U0C0_TRBPTRL    (*(_PAGE_081_MEM_TYPE(0x204108))) /* Transmit/Receive Buffer Pointer Register L */


#define U0C0_TRBPTRH    (*(_PAGE_081_MEM_TYPE(0x20410A))) /* Transmit/Receive Buffer Pointer Register H */

#endif /* REGXC2310S_NOUSIC0 */

/********************************************************************************
 * USIC
********************************************************************************/
#ifndef REGXC2310S_NOUSIC


#define U0C0_IDL        (*(_PAGE_102_MEM_TYPE(0x408008))) /* Module Identification Register L */


#define U0C0_IDH        (*(_PAGE_102_MEM_TYPE(0x40800A))) /* Module Identification Register H */


#define U0C1_CCR        (*(_PAGE_081_MEM_TYPE(0x204210))) /* Channel Control Register */


#define U0C1_CCFG       (*(_PAGE_081_MEM_TYPE(0x204218))) /* Channel Configuration Register */


#define U0C1_KSCFG      (*(_PAGE_081_MEM_TYPE(0x20420C))) /* Kernel State Configuration Register */


#define U0C1_INPRL      (*(_PAGE_081_MEM_TYPE(0x204214))) /* Interrupt Node Pointer Register L */


#define U0C1_INPRH      (*(_PAGE_081_MEM_TYPE(0x204216))) /* Interrupt Node Pointer Register H */


#define U0C1_PCRL       (*(_PAGE_081_MEM_TYPE(0x204240))) /* Protocol Control Register L */


#define U0C1_PCRH       (*(_PAGE_081_MEM_TYPE(0x204242))) /* Protocol Control Register H */


#define U0C1_PSR        (*(_PAGE_081_MEM_TYPE(0x204244))) /* Protocol Status Register */


#define U0C1_PSCR       (*(_PAGE_081_MEM_TYPE(0x204248))) /* Protocol Status Clear Register */


#define U0C1_DX0CR      (*(_PAGE_081_MEM_TYPE(0x204220))) /* Input Control Register 0 */


#define U0C1_DX1CR      (*(_PAGE_081_MEM_TYPE(0x204224))) /* Input Control Register 1 */


#define U0C1_DX2CR      (*(_PAGE_081_MEM_TYPE(0x204228))) /* Input Control Register 2 */


#define U0C1_FDRL       (*(_PAGE_081_MEM_TYPE(0x204204))) /* Fractional Divider Register L */


#define U0C1_FDRH       (*(_PAGE_081_MEM_TYPE(0x204206))) /* Fractional Divider Register H */


#define U0C1_BRGL       (*(_PAGE_081_MEM_TYPE(0x20421C))) /* Baud Rate Generator Register L */


#define U0C1_BRGH       (*(_PAGE_081_MEM_TYPE(0x20421E))) /* Baud Rate Generator Register H */


#define U0C1_SCTRL      (*(_PAGE_081_MEM_TYPE(0x204230))) /* Shift Control Register L */


#define U0C1_SCTRH      (*(_PAGE_081_MEM_TYPE(0x204232))) /* Shift Control Register H */


#define U0C1_TCSRL      (*(_PAGE_081_MEM_TYPE(0x20423C))) /* Transmit Control/Status Register L */


#define U0C1_TCSRH      (*(_PAGE_081_MEM_TYPE(0x20423E))) /* Transmit Control/Status Register H */


#define U0C1_FMRL       (*(_PAGE_081_MEM_TYPE(0x204238))) /* Flag Modification Register L */


#define U0C1_FMRH       (*(_PAGE_081_MEM_TYPE(0x20423A))) /* Flag Modification Register H */


#define U0C1_TBUF00     (*(_PAGE_081_MEM_TYPE(0x204280))) /* Transmit Buffer Input Location 00 */


#define U0C1_TBUF01     (*(_PAGE_081_MEM_TYPE(0x204284))) /* Transmit Buffer Input Location 01 */


#define U0C1_TBUF02     (*(_PAGE_081_MEM_TYPE(0x204288))) /* Transmit Buffer Input Location 02 */


#define U0C1_TBUF03     (*(_PAGE_081_MEM_TYPE(0x20428C))) /* Transmit Buffer Input Location 03 */


#define U0C1_TBUF04     (*(_PAGE_081_MEM_TYPE(0x204290))) /* Transmit Buffer Input Location 04 */


#define U0C1_TBUF05     (*(_PAGE_081_MEM_TYPE(0x204294))) /* Transmit Buffer Input Location 05 */


#define U0C1_TBUF06     (*(_PAGE_081_MEM_TYPE(0x204298))) /* Transmit Buffer Input Location 06 */


#define U0C1_TBUF07     (*(_PAGE_081_MEM_TYPE(0x20429C))) /* Transmit Buffer Input Location 07 */


#define U0C1_TBUF08     (*(_PAGE_081_MEM_TYPE(0x2042A0))) /* Transmit Buffer Input Location 08 */


#define U0C1_TBUF09     (*(_PAGE_081_MEM_TYPE(0x2042A4))) /* Transmit Buffer Input Location 09 */


#define U0C1_TBUF10     (*(_PAGE_081_MEM_TYPE(0x2042A8))) /* Transmit Buffer Input Location 10 */


#define U0C1_TBUF11     (*(_PAGE_081_MEM_TYPE(0x2042AC))) /* Transmit Buffer Input Location 11 */


#define U0C1_TBUF12     (*(_PAGE_081_MEM_TYPE(0x2042B0))) /* Transmit Buffer Input Location 12 */


#define U0C1_TBUF13     (*(_PAGE_081_MEM_TYPE(0x2042B4))) /* Transmit Buffer Input Location 13 */


#define U0C1_TBUF14     (*(_PAGE_081_MEM_TYPE(0x2042B8))) /* Transmit Buffer Input Location 14 */


#define U0C1_TBUF15     (*(_PAGE_081_MEM_TYPE(0x2042BC))) /* Transmit Buffer Input Location 15 */


#define U0C1_TBUF16     (*(_PAGE_081_MEM_TYPE(0x2042C0))) /* Transmit Buffer Input Location 16 */


#define U0C1_TBUF17     (*(_PAGE_081_MEM_TYPE(0x2042C4))) /* Transmit Buffer Input Location 17 */


#define U0C1_TBUF18     (*(_PAGE_081_MEM_TYPE(0x2042C8))) /* Transmit Buffer Input Location 18 */


#define U0C1_TBUF19     (*(_PAGE_081_MEM_TYPE(0x2042CC))) /* Transmit Buffer Input Location 19 */


#define U0C1_TBUF20     (*(_PAGE_081_MEM_TYPE(0x2042D0))) /* Transmit Buffer Input Location 20 */


#define U0C1_TBUF21     (*(_PAGE_081_MEM_TYPE(0x2042D4))) /* Transmit Buffer Input Location 21 */


#define U0C1_TBUF22     (*(_PAGE_081_MEM_TYPE(0x2042D8))) /* Transmit Buffer Input Location 22 */


#define U0C1_TBUF23     (*(_PAGE_081_MEM_TYPE(0x2042DC))) /* Transmit Buffer Input Location 23 */


#define U0C1_TBUF24     (*(_PAGE_081_MEM_TYPE(0x2042E0))) /* Transmit Buffer Input Location 24 */


#define U0C1_TBUF25     (*(_PAGE_081_MEM_TYPE(0x2042E4))) /* Transmit Buffer Input Location 25 */


#define U0C1_TBUF26     (*(_PAGE_081_MEM_TYPE(0x2042E8))) /* Transmit Buffer Input Location 26 */


#define U0C1_TBUF27     (*(_PAGE_081_MEM_TYPE(0x2042EC))) /* Transmit Buffer Input Location 27 */


#define U0C1_TBUF28     (*(_PAGE_081_MEM_TYPE(0x2042F0))) /* Transmit Buffer Input Location 28 */


#define U0C1_TBUF29     (*(_PAGE_081_MEM_TYPE(0x2042F4))) /* Transmit Buffer Input Location 29 */


#define U0C1_TBUF30     (*(_PAGE_081_MEM_TYPE(0x2042F8))) /* Transmit Buffer Input Location 30 */


#define U0C1_TBUF31     (*(_PAGE_081_MEM_TYPE(0x2042FC))) /* Transmit Buffer Input Location 31 */


#define U0C1_RBUF0      (*(_PAGE_081_MEM_TYPE(0x204250))) /* Receiver Buffer Register 0 */


#define U0C1_RBUF01SRL  (*(_PAGE_081_MEM_TYPE(0x204260))) /* Receiver Buffer 01 Status Register L */


#define U0C1_RBUF1      (*(_PAGE_081_MEM_TYPE(0x204254))) /* Receiver Buffer Register 1 */


#define U0C1_RBUF01SRH  (*(_PAGE_081_MEM_TYPE(0x204262))) /* Receiver Buffer 01 Status Register H */


#define U0C1_RBUF       (*(_PAGE_081_MEM_TYPE(0x20425C))) /* Receiver Buffer Register */


#define U0C1_RBUFD      (*(_PAGE_081_MEM_TYPE(0x20424C))) /* Receiver Buffer Register for Debugger */


#define U0C1_RBUFSR     (*(_PAGE_081_MEM_TYPE(0x204258))) /* Receiver Buffer Status Register */


#define U0C1_BYP        (*(_PAGE_081_MEM_TYPE(0x204300))) /* Bypass Data Register */


#define U0C1_BYPCRL     (*(_PAGE_081_MEM_TYPE(0x204304))) /* Bypass Control Register L */


#define U0C1_BYPCRH     (*(_PAGE_081_MEM_TYPE(0x204306))) /* Bypass Control Register H */


#define U0C1_TRBSRL     (*(_PAGE_081_MEM_TYPE(0x204318))) /* Transmit/Receive Buffer Status Register L */


#define U0C1_TRBSRH     (*(_PAGE_081_MEM_TYPE(0x20431A))) /* Transmit/Receive Buffer Status Register H */


#define U0C1_TRBSCR     (*(_PAGE_081_MEM_TYPE(0x20431C))) /* Transmit/Receive Buffer Status Clear Register */


#define U0C1_TBCTRL     (*(_PAGE_081_MEM_TYPE(0x204310))) /* Transmitter Buffer Control Register L */


#define U0C1_TBCTRH     (*(_PAGE_081_MEM_TYPE(0x204312))) /* Transmitter Buffer Control Register H */


#define U0C1_RBCTRL     (*(_PAGE_081_MEM_TYPE(0x204314))) /* Receiver Buffer Control Register L */


#define U0C1_RBCTRH     (*(_PAGE_081_MEM_TYPE(0x204316))) /* Receiver Buffer Control Register H */


#define U0C1_IN00       (*(_PAGE_081_MEM_TYPE(0x204380))) /* Transmit FIFO Buffer Input Location 00 */


#define U0C1_IN01       (*(_PAGE_081_MEM_TYPE(0x204384))) /* Transmit FIFO Buffer Input Location 01 */


#define U0C1_IN02       (*(_PAGE_081_MEM_TYPE(0x204388))) /* Transmit FIFO Buffer Input Location 02 */


#define U0C1_IN03       (*(_PAGE_081_MEM_TYPE(0x20438C))) /* Transmit FIFO Buffer Input Location 03 */


#define U0C1_IN04       (*(_PAGE_081_MEM_TYPE(0x204390))) /* Transmit FIFO Buffer Input Location 04 */


#define U0C1_IN05       (*(_PAGE_081_MEM_TYPE(0x204394))) /* Transmit FIFO Buffer Input Location 05 */


#define U0C1_IN06       (*(_PAGE_081_MEM_TYPE(0x204398))) /* Transmit FIFO Buffer Input Location 06 */


#define U0C1_IN07       (*(_PAGE_081_MEM_TYPE(0x20439C))) /* Transmit FIFO Buffer Input Location 07 */


#define U0C1_IN08       (*(_PAGE_081_MEM_TYPE(0x2043A0))) /* Transmit FIFO Buffer Input Location 08 */


#define U0C1_IN09       (*(_PAGE_081_MEM_TYPE(0x2043A4))) /* Transmit FIFO Buffer Input Location 09 */


#define U0C1_IN10       (*(_PAGE_081_MEM_TYPE(0x2043A8))) /* Transmit FIFO Buffer Input Location 10 */


#define U0C1_IN11       (*(_PAGE_081_MEM_TYPE(0x2043AC))) /* Transmit FIFO Buffer Input Location 11 */


#define U0C1_IN12       (*(_PAGE_081_MEM_TYPE(0x2043B0))) /* Transmit FIFO Buffer Input Location 12 */


#define U0C1_IN13       (*(_PAGE_081_MEM_TYPE(0x2043B4))) /* Transmit FIFO Buffer Input Location 13 */


#define U0C1_IN14       (*(_PAGE_081_MEM_TYPE(0x2043B8))) /* Transmit FIFO Buffer Input Location 14 */


#define U0C1_IN15       (*(_PAGE_081_MEM_TYPE(0x2043BC))) /* Transmit FIFO Buffer Input Location 15 */


#define U0C1_IN16       (*(_PAGE_081_MEM_TYPE(0x2043C0))) /* Transmit FIFO Buffer Input Location 16 */


#define U0C1_IN17       (*(_PAGE_081_MEM_TYPE(0x2043C4))) /* Transmit FIFO Buffer Input Location 17 */


#define U0C1_IN18       (*(_PAGE_081_MEM_TYPE(0x2043C8))) /* Transmit FIFO Buffer Input Location 18 */


#define U0C1_IN19       (*(_PAGE_081_MEM_TYPE(0x2043CC))) /* Transmit FIFO Buffer Input Location 19 */


#define U0C1_IN20       (*(_PAGE_081_MEM_TYPE(0x2043D0))) /* Transmit FIFO Buffer Input Location 20 */


#define U0C1_IN21       (*(_PAGE_081_MEM_TYPE(0x2043D4))) /* Transmit FIFO Buffer Input Location 21 */


#define U0C1_IN22       (*(_PAGE_081_MEM_TYPE(0x2043D8))) /* Transmit FIFO Buffer Input Location 22 */


#define U0C1_IN23       (*(_PAGE_081_MEM_TYPE(0x2043DC))) /* Transmit FIFO Buffer Input Location 23 */


#define U0C1_IN24       (*(_PAGE_081_MEM_TYPE(0x2043E0))) /* Transmit FIFO Buffer Input Location 24 */


#define U0C1_IN25       (*(_PAGE_081_MEM_TYPE(0x2043E4))) /* Transmit FIFO Buffer Input Location 25 */


#define U0C1_IN26       (*(_PAGE_081_MEM_TYPE(0x2043E8))) /* Transmit FIFO Buffer Input Location 26 */


#define U0C1_IN27       (*(_PAGE_081_MEM_TYPE(0x2043EC))) /* Transmit FIFO Buffer Input Location 27 */


#define U0C1_IN28       (*(_PAGE_081_MEM_TYPE(0x2043F0))) /* Transmit FIFO Buffer Input Location 28 */


#define U0C1_IN29       (*(_PAGE_081_MEM_TYPE(0x2043F4))) /* Transmit FIFO Buffer Input Location 29 */


#define U0C1_IN30       (*(_PAGE_081_MEM_TYPE(0x2043F8))) /* Transmit FIFO Buffer Input Location 30 */


#define U0C1_IN31       (*(_PAGE_081_MEM_TYPE(0x2043FC))) /* Transmit FIFO Buffer Input Location 31 */


#define U0C1_OUTRL      (*(_PAGE_081_MEM_TYPE(0x204320))) /* Receiver Buffer Output Register L */


#define U0C1_OUTRH      (*(_PAGE_081_MEM_TYPE(0x204322))) /* Receiver Buffer Output Register H */


#define U0C1_OUTDRL     (*(_PAGE_081_MEM_TYPE(0x204324))) /* Receiver Buffer Output Register L for Debugger */


#define U0C1_OUTDRH     (*(_PAGE_081_MEM_TYPE(0x204326))) /* Receiver Buffer Output Register H for Debugger */


#define U0C1_TRBPTRL    (*(_PAGE_081_MEM_TYPE(0x204308))) /* Transmit/Receive Buffer Pointer Register L */


#define U0C1_TRBPTRH    (*(_PAGE_081_MEM_TYPE(0x20430A))) /* Transmit/Receive Buffer Pointer Register H */


#define U0C1_IDL        (*(_PAGE_102_MEM_TYPE(0x408208))) /* Module Identification Register L */


#define U0C1_IDH        (*(_PAGE_102_MEM_TYPE(0x40820A))) /* Module Identification Register H */


#define U0C0A_IDL       (*(_PAGE_103_MEM_TYPE(0x40F008))) /* Module Identification Register L */


#define U0C0A_IDH       (*(_PAGE_103_MEM_TYPE(0x40F00A))) /* Module Identification Register H */


#define U0C1A_IDL       (*(_PAGE_103_MEM_TYPE(0x40F208))) /* Module Identification Register L */


#define U0C1A_IDH       (*(_PAGE_103_MEM_TYPE(0x40F20A))) /* Module Identification Register H */

#endif /* REGXC2310S_NOUSIC */

/********************************************************************************
 * GPT12
********************************************************************************/
#ifndef REGXC2310S_NOGPT12

_sfr GPT12E_T2;                         /* Timer 2 */

#define T2              GPT12E_T2

_sfr GPT12E_T3;                         /* Timer 3 */

#define T3              GPT12E_T3

_sfr GPT12E_T4;                         /* Timer 4 */

#define T4              GPT12E_T4

_sfr GPT12E_T3CON;                      /* Timer 3 Control Register */
_sfrbit GPT12E_T3CON_T3R;               /* GPT12E_T3CON.6: <GPT12E_T3CON_T3R> */
_sfrbit GPT12E_T3CON_T3UD;              /* GPT12E_T3CON.7: <GPT12E_T3CON_T3UD> */
_sfrbit GPT12E_T3CON_T3UDE;             /* GPT12E_T3CON.8: <GPT12E_T3CON_T3UDE> */
_sfrbit GPT12E_T3CON_T3OE;              /* GPT12E_T3CON.9: <GPT12E_T3CON_T3OE> */
_sfrbit GPT12E_T3CON_T3OTL;             /* GPT12E_T3CON.10: <GPT12E_T3CON_T3OTL> */
_sfrbit GPT12E_T3CON_T3EDGE;            /* GPT12E_T3CON.13: <GPT12E_T3CON_T3EDGE> */
_sfrbit GPT12E_T3CON_T3CHDIR;           /* GPT12E_T3CON.14: <GPT12E_T3CON_T3CHDIR> */
_sfrbit GPT12E_T3CON_T3RDIR;            /* GPT12E_T3CON.15: <GPT12E_T3CON_T3RDIR> */

#define T3R             GPT12E_T3CON_T3R
#define T3CON           GPT12E_T3CON

_sfr GPT12E_T2CON;                      /* Timer 2 Control Register */
_sfrbit GPT12E_T2CON_T2R;               /* GPT12E_T2CON.6: <GPT12E_T2CON_T2R> */
_sfrbit GPT12E_T2CON_T2UD;              /* GPT12E_T2CON.7: <GPT12E_T2CON_T2UD> */
_sfrbit GPT12E_T2CON_T2UDE;             /* GPT12E_T2CON.8: <GPT12E_T2CON_T2UDE> */
_sfrbit GPT12E_T2CON_T2RC;              /* GPT12E_T2CON.9: <GPT12E_T2CON_T2RC> */
_sfrbit GPT12E_T2CON_T2IRDIS;           /* GPT12E_T2CON.12: <GPT12E_T2CON_T2IRDIS> */
_sfrbit GPT12E_T2CON_T2EDGE;            /* GPT12E_T2CON.13: <GPT12E_T2CON_T2EDGE> */
_sfrbit GPT12E_T2CON_T2CHDIR;           /* GPT12E_T2CON.14: <GPT12E_T2CON_T2CHDIR> */
_sfrbit GPT12E_T2CON_T2RDIR;            /* GPT12E_T2CON.15: <GPT12E_T2CON_T2RDIR> */

#define T2R             GPT12E_T2CON_T2R
#define T2CON           GPT12E_T2CON

_sfr GPT12E_T4CON;                      /* Timer 4 Control Register */
_sfrbit GPT12E_T4CON_T4R;               /* GPT12E_T4CON.6: <GPT12E_T4CON_T4R> */
_sfrbit GPT12E_T4CON_T4UD;              /* GPT12E_T4CON.7: <GPT12E_T4CON_T4UD> */
_sfrbit GPT12E_T4CON_T4UDE;             /* GPT12E_T4CON.8: <GPT12E_T4CON_T4UDE> */
_sfrbit GPT12E_T4CON_T4RC;              /* GPT12E_T4CON.9: <GPT12E_T4CON_T4RC> */
_sfrbit GPT12E_T4CON_CLRT2EN;           /* GPT12E_T4CON.10: <GPT12E_T4CON_CLRT2EN> */
_sfrbit GPT12E_T4CON_CLRT3EN;           /* GPT12E_T4CON.11: <GPT12E_T4CON_CLRT3EN> */
_sfrbit GPT12E_T4CON_T4IRDIS;           /* GPT12E_T4CON.12: <GPT12E_T4CON_T4IRDIS> */
_sfrbit GPT12E_T4CON_T4EDGE;            /* GPT12E_T4CON.13: <GPT12E_T4CON_T4EDGE> */
_sfrbit GPT12E_T4CON_T4CHDIR;           /* GPT12E_T4CON.14: <GPT12E_T4CON_T4CHDIR> */
_sfrbit GPT12E_T4CON_T4RDIR;            /* GPT12E_T4CON.15: <GPT12E_T4CON_T4RDIR> */

#define T4R             GPT12E_T4CON_T4R
#define T4CON           GPT12E_T4CON

_sfr GPT12E_T5;                         /* Timer 5 */

#define T5              GPT12E_T5

_sfr GPT12E_T6;                         /* Timer 6 */

#define T6              GPT12E_T6

_sfr GPT12E_CAPREL;                     /* Capture/Reload Register */

#define CAPREL          GPT12E_CAPREL

_sfr GPT12E_T6CON;                      /* Timer 6 Control Register */
_sfrbit GPT12E_T6CON_T6R;               /* GPT12E_T6CON.6: <GPT12E_T6CON_T6R> */
_sfrbit GPT12E_T6CON_T6UD;              /* GPT12E_T6CON.7: <GPT12E_T6CON_T6UD> */
_sfrbit GPT12E_T6CON_T6UDE;             /* GPT12E_T6CON.8: <GPT12E_T6CON_T6UDE> */
_sfrbit GPT12E_T6CON_T6OE;              /* GPT12E_T6CON.9: <GPT12E_T6CON_T6OE> */
_sfrbit GPT12E_T6CON_T6OTL;             /* GPT12E_T6CON.10: <GPT12E_T6CON_T6OTL> */
_sfrbit GPT12E_T6CON_T6CLR;             /* GPT12E_T6CON.14: <GPT12E_T6CON_T6CLR> */
_sfrbit GPT12E_T6CON_T6SR;              /* GPT12E_T6CON.15: <GPT12E_T6CON_T6SR> */

#define T6R             GPT12E_T6CON_T6R
#define T6CON           GPT12E_T6CON

_sfr GPT12E_T5CON;                      /* Timer 5 Control Register */
_sfrbit GPT12E_T5CON_T5R;               /* GPT12E_T5CON.6: <GPT12E_T5CON_T5R> */
_sfrbit GPT12E_T5CON_T5UD;              /* GPT12E_T5CON.7: <GPT12E_T5CON_T5UD> */
_sfrbit GPT12E_T5CON_T5UDE;             /* GPT12E_T5CON.8: <GPT12E_T5CON_T5UDE> */
_sfrbit GPT12E_T5CON_T5RC;              /* GPT12E_T5CON.9: <GPT12E_T5CON_T5RC> */
_sfrbit GPT12E_T5CON_CT3;               /* GPT12E_T5CON.10: <GPT12E_T5CON_CT3> */
_sfrbit GPT12E_T5CON_T5CLR;             /* GPT12E_T5CON.14: <GPT12E_T5CON_T5CLR> */
_sfrbit GPT12E_T5CON_T5SC;              /* GPT12E_T5CON.15: <GPT12E_T5CON_T5SC> */

#define T5R             GPT12E_T5CON_T5R
#define T5CON           GPT12E_T5CON

_sfr GPT12E_PISEL;                      /* Port Input Select Register */

_sfr GPT12E_ID;                         /* GPT12E Module Identification Register */

#endif /* REGXC2310S_NOGPT12 */

/********************************************************************************
 * RTC
********************************************************************************/
#ifndef REGXC2310S_NORTC

_esfr RTC_CON;                          /* Control Register */
_esfrbit RTC_CON_RUN;                   /* RTC_CON.0: RTC Run Bit */
_esfrbit RTC_CON_PRE;                   /* RTC_CON.1: RTC Input Source Prescaler (8:1) enable */
_esfrbit RTC_CON_T14DEC;                /* RTC_CON.2: Decrement T14 Timer Value */
_esfrbit RTC_CON_T14INC;                /* RTC_CON.3: Increment T14 Timer Value */
_esfrbit RTC_CON_REFCLK;                /* RTC_CON.4: RTC Input Source Prescaler (32:1) disable */
_esfrbit RTC_CON_ACCPOS;                /* RTC_CON.15: RTC register access possible */

_esfr RTC_T14;                          /* T14 Count Register */

_esfr RTC_T14REL;                       /* T14 Reload Register */

_esfr RTC_RTCL;                         /* RTC Count Register Low */

_esfr RTC_RTCH;                         /* RTC Count Register High */

_esfr RTC_RELL;                         /* RTC Reload Register Low */

_esfr RTC_RELH;                         /* RTC Reload Register High */

_esfr RTC_ISNC;                         /* Interrupt Sub Node Control */
_esfrbit RTC_ISNC_T14IE;                /* RTC_ISNC.0: T14 Overflow Interrupt Enable Control Bit */
_esfrbit RTC_ISNC_T14IR;                /* RTC_ISNC.1: T14 Overflow Interrupt Request Bit (bit protected) */
_esfrbit RTC_ISNC_CNT0IE;               /* RTC_ISNC.2: Count x Overflow Interrupt Enable Control */
_esfrbit RTC_ISNC_CNT0IR;               /* RTC_ISNC.3: Count x Overflow Interrupt Request Bit (bit protected) */
_esfrbit RTC_ISNC_CNT1IE;               /* RTC_ISNC.4: Count x Overflow Interrupt Enable Control */
_esfrbit RTC_ISNC_CNT1IR;               /* RTC_ISNC.5: Count x Overflow Interrupt Request Bit (bit protected) */
_esfrbit RTC_ISNC_CNT2IE;               /* RTC_ISNC.6: Count x Overflow Interrupt Enable Control */
_esfrbit RTC_ISNC_CNT2IR;               /* RTC_ISNC.7: Count x Overflow Interrupt Request Bit (bit protected) */
_esfrbit RTC_ISNC_CNT3IE;               /* RTC_ISNC.8: Count x Overflow Interrupt Enable Control */
_esfrbit RTC_ISNC_CNT3IR;               /* RTC_ISNC.9: Count x Overflow Interrupt Request Bit (bit protected) */

#endif /* REGXC2310S_NORTC */

/********************************************************************************
 * CC2
********************************************************************************/
#ifndef REGXC2310S_NOCC2

_sfr CC2_ID;                            /* CAPCOM2 Identification Register MEM */

_esfr CC2_T7;                           /* CAPCOM2 Timer 7 Register */

_esfr CC2_T8;                           /* CAPCOM2 Timer 8 Register */

_esfr CC2_T7REL;                        /* CAPCOM2 Timer 7 Reload Register */

_esfr CC2_T8REL;                        /* CAPCOM2 Timer 8 Reload Register */

_sfr CC2_T78CON;                        /* CAPCOM2 Timer 7/8 Control Register */
_sfrbit CC2_T78CON_T7M;                 /* CC2_T78CON.3: Timer / Counter x Mode Selection */
_sfrbit CC2_T78CON_T7R;                 /* CC2_T78CON.6: Timer / Counter x Run Control */
_sfrbit CC2_T78CON_T8M;                 /* CC2_T78CON.11: Timer / Counter x Mode Selection */
_sfrbit CC2_T78CON_T8R;                 /* CC2_T78CON.14: Timer / Counter x Run Control */

_sfr CC2_CC16;                          /* CAPCOM2 Capture/Compare Register 16 */

_sfr CC2_CC17;                          /* CAPCOM2 Capture/Compare Register 17 */

_sfr CC2_CC18;                          /* CAPCOM2 Capture/Compare Register 18 */

_sfr CC2_CC19;                          /* CAPCOM2 Capture/Compare Register 19 */

_sfr CC2_CC20;                          /* CAPCOM2 Capture/Compare Register 20 */

_sfr CC2_CC21;                          /* CAPCOM2 Capture/Compare Register 21 */

_sfr CC2_CC22;                          /* CAPCOM2 Capture/Compare Register 22 */

_sfr CC2_CC23;                          /* CAPCOM2 Capture/Compare Register 23 */

_sfr CC2_CC24;                          /* CAPCOM2 Capture/Compare Register 24 */

_sfr CC2_CC25;                          /* CAPCOM2 Capture/Compare Register 25 */

_sfr CC2_CC26;                          /* CAPCOM2 Capture/Compare Register 26 */

_sfr CC2_CC27;                          /* CAPCOM2 Capture/Compare Register 27 */

_sfr CC2_CC28;                          /* CAPCOM2 Capture/Compare Register 28 */

_sfr CC2_CC29;                          /* CAPCOM2 Capture/Compare Register 29 */

_sfr CC2_CC30;                          /* CAPCOM2 Capture/Compare Register 30 */

_sfr CC2_CC31;                          /* CAPCOM2 Capture/Compare Register 31 */

_sfr CC2_M4;                            /* CAPCOM2 Mode Control Register 4 */
_sfrbit CC2_M4_ACC16;                   /* CC2_M4.3: Allocation Bit for CAPCOM Register CCy (y = 16-19) */
_sfrbit CC2_M4_ACC17;                   /* CC2_M4.7: Allocation Bit for CAPCOM Register CCy (y = 16-19) */
_sfrbit CC2_M4_ACC18;                   /* CC2_M4.11: Allocation Bit for CAPCOM Register CCy (y = 16-19) */
_sfrbit CC2_M4_ACC19;                   /* CC2_M4.15: Allocation Bit for CAPCOM Register CCy (y = 16-19) */

_sfr CC2_M5;                            /* CAPCOM2 Mode Control Register 5 */
_sfrbit CC2_M5_ACC20;                   /* CC2_M5.3: Allocation Bit for CAPCOM Register CCy (y = 20-23) */
_sfrbit CC2_M5_ACC21;                   /* CC2_M5.7: Allocation Bit for CAPCOM Register CCy (y = 20-23) */
_sfrbit CC2_M5_ACC22;                   /* CC2_M5.11: Allocation Bit for CAPCOM Register CCy (y = 20-23) */
_sfrbit CC2_M5_ACC23;                   /* CC2_M5.15: Allocation Bit for CAPCOM Register CCy (y = 20-23) */

_sfr CC2_M6;                            /* CAPCOM2 Mode Control Register 6 */
_sfrbit CC2_M6_ACC24;                   /* CC2_M6.3: Allocation Bit for CAPCOM Register CCy (y = 24-28) */
_sfrbit CC2_M6_ACC25;                   /* CC2_M6.7: Allocation Bit for CAPCOM Register CCy (y = 24-28) */
_sfrbit CC2_M6_ACC26;                   /* CC2_M6.11: Allocation Bit for CAPCOM Register CCy (y = 24-28) */
_sfrbit CC2_M6_ACC27;                   /* CC2_M6.15: Allocation Bit for CAPCOM Register CCy (y = 24-28) */

_sfr CC2_M7;                            /* CAPCOM2 Mode Control Register 7 */
_sfrbit CC2_M7_ACC28;                   /* CC2_M7.3: Allocation Bit for CAPCOM Register CCy (y = 28-31) */
_sfrbit CC2_M7_ACC29;                   /* CC2_M7.7: Allocation Bit for CAPCOM Register CCy (y = 28-31) */
_sfrbit CC2_M7_ACC30;                   /* CC2_M7.11: Allocation Bit for CAPCOM Register CCy (y = 28-31) */
_sfrbit CC2_M7_ACC31;                   /* CC2_M7.15: Allocation Bit for CAPCOM Register CCy (y = 28-31) */

_sfr CC2_OUT;                           /* CAPCOM2 Compare Output Register */
_sfrbit CC2_OUT_CC16IO;                 /* CC2_OUT.0: Compare Output for Channel y */
_sfrbit CC2_OUT_CC17IO;                 /* CC2_OUT.1: Compare Output for Channel y */
_sfrbit CC2_OUT_CC18IO;                 /* CC2_OUT.2: Compare Output for Channel y */
_sfrbit CC2_OUT_CC19IO;                 /* CC2_OUT.3: Compare Output for Channel y */
_sfrbit CC2_OUT_CC20IO;                 /* CC2_OUT.4: Compare Output for Channel y */
_sfrbit CC2_OUT_CC21IO;                 /* CC2_OUT.5: Compare Output for Channel y */
_sfrbit CC2_OUT_CC22IO;                 /* CC2_OUT.6: Compare Output for Channel y */
_sfrbit CC2_OUT_CC23IO;                 /* CC2_OUT.7: Compare Output for Channel y */
_sfrbit CC2_OUT_CC24IO;                 /* CC2_OUT.8: Compare Output for Channel y */
_sfrbit CC2_OUT_CC25IO;                 /* CC2_OUT.9: Compare Output for Channel y */
_sfrbit CC2_OUT_CC26IO;                 /* CC2_OUT.10: Compare Output for Channel y */
_sfrbit CC2_OUT_CC27IO;                 /* CC2_OUT.11: Compare Output for Channel y */
_sfrbit CC2_OUT_CC28IO;                 /* CC2_OUT.12: Compare Output for Channel y */
_sfrbit CC2_OUT_CC29IO;                 /* CC2_OUT.13: Compare Output for Channel y */
_sfrbit CC2_OUT_CC30IO;                 /* CC2_OUT.14: Compare Output for Channel y */
_sfrbit CC2_OUT_CC31IO;                 /* CC2_OUT.15: Compare Output for Channel y */

_sfr CC2_DRM;                           /* CAPCOM2 Double-Register Compare Mode Register */

_esfr CC2_IOC;                          /* CAPCOM2 I/O Control Register */

_sfr CC2_SEM;                           /* CAPCOM2 Single Event Mode Control Register */

_sfr CC2_SEE;                           /* CAPCOM2 Single Event Enable Register */

#endif /* REGXC2310S_NOCC2 */

/********************************************************************************
 * CCU6
********************************************************************************/
#ifndef REGXC2310S_NOCCU6

_xsfr CCU60_T12;                        /* Timer T12 Counter Register */

_xsfr CCU60_T12PR;                      /* Timer 12 Period Register */

_xsfr CCU60_CC60R;                      /* Capture/Compare Register for Channel CC60 */

_xsfr CCU60_CC61R;                      /* Capture/Compare Register for Channel CC61 */

_xsfr CCU60_CC62R;                      /* Capture/Compare Register for Channel CC62 */

_xsfr CCU60_CC60SR;                     /* Capture/Compare Shadow Reg. for Channel CC60 */

_xsfr CCU60_CC61SR;                     /* Capture/Compare Shadow Reg. for Channel CC61 */

_xsfr CCU60_CC62SR;                     /* Capture/Compare Shadow Reg. for Channel CC62 */

_xsfr CCU60_T12DTC;                     /* Dead-Time Control Register for Timer12 */

_xsfr CCU60_CMPSTAT;                    /* Compare State Register */

_xsfr CCU60_CMPMODIF;                   /* Compare State Modification Register */

_xsfr CCU60_T12MSEL;                    /* T12 Mode Select Register */

_xsfr CCU60_TCTR0;                      /* Timer Control Register 0 */

_xsfr CCU60_TCTR2;                      /* Timer Control Register 2 */

_xsfr CCU60_TCTR4;                      /* Timer Control Register 4 */

_xsfr CCU60_T13;                        /* Timer T13 Counter Register */

_xsfr CCU60_T13PR;                      /* Timer 13 Period Register */

_xsfr CCU60_CC63R;                      /* Compare Register for T13 */

_xsfr CCU60_CC63SR;                     /* Compare Shadow Register for T13 */

_xsfr CCU60_MODCTR;                     /* Modulation Control Register */

_xsfr CCU60_TRPCTR;                     /* Trap Control Register */

_xsfr CCU60_PSLR;                       /* Passive State Level Register */

_xsfr CCU60_MCMCTR;                     /* Multi-Channel Mode Control Register */

_xsfr CCU60_MCMOUTS;                    /* Multi-Channel Mode Output Shadow Register */

_xsfr CCU60_MCMOUT;                     /* Multi-Channel Mode Output Register */

_xsfr CCU60_IS;                         /* Interrupt Status Register */

_xsfr CCU60_ISS;                        /* Interrupt Status Set Register */

_xsfr CCU60_ISR;                        /* Interrupt Status Reset Register */

_xsfr CCU60_IEN;                        /* Interrupt Enable Register */

_xsfr CCU60_INP;                        /* Interrupt Node Pointer Register */

_xsfr CCU60_ID;                         /* Module Identification Register */

_xsfr CCU60_PISELL;                     /* Port Input Select Register Low */

_xsfr CCU60_PISELH;                     /* Port Input Select Register High */

_xsfr CCU60_KSCFG;                      /* Kernel State Configuration Register */

_xsfr CCU60_KSCSR;                      /* Kernel State Control Sensitivity Register */

#endif /* REGXC2310S_NOCCU6 */

/********************************************************************************
 * Analog/Digital Convertor Control Registers
********************************************************************************/
#ifndef REGXC2310S_NOADC

_xsfr ADC0_KSCFG;                       /* Kernel State Configuration Register */

_xsfr ADC0_ID;                          /* Module Identification Register */

_xsfr ADC0_GLOBCTR;                     /* Global Control Register */

_xsfr ADC0_GLOBCFG;                     /* Global Configuration Register */

_xsfr ADC0_GLOBSTR;                     /* Global Status Register */

_xsfr ADC0_CRMR1;                       /* Conversion Request 1 Mode Register */

_xsfr ADC0_CRCR1;                       /* Conversion Request 1 Control Register */

_xsfr ADC0_CRCR1E;                      /* Conversion Request 1 Control Register Extended */

_xsfr ADC0_CRPR1;                       /* Conversion Request 1 Pending Register */

_xsfr ADC0_CRPR1E;                      /* Conversion Request 1 Pending Register Extended */

_xsfr ADC0_QMR0;                        /* Queue 0 Mode Register */

_xsfr ADC0_QMR2;                        /* Queue 2 Mode Register */

_xsfr ADC0_QSR0;                        /* Queue 0 Status Register */

_xsfr ADC0_QSR2;                        /* Queue 2 Status Register */

_xsfr ADC0_QINR0;                       /* Queue 0 Input Register */

_xsfr ADC0_QINR2;                       /* Queue 2 Input Register */

_xsfr ADC0_Q0R0;                        /* Queue 0 Register 0 */

_xsfr ADC0_Q0R2;                        /* Queue 2 Register 0 */

_xsfr ADC0_RSIR0;                       /* Request Source 0 Input Register */

_xsfr ADC0_RSIR1;                       /* Request Source 1 Input Register */

_xsfr ADC0_RSIR2;                       /* Request Source 2 Input Register */

_xsfr ADC0_ASENR;                       /* Arbitration Slot Enable Register */

_xsfr ADC0_RSPR0;                       /* Request Source Priority Register 0 */

_xsfr ADC0_CHCTR0;                      /* Channel 0 Control Register */

_xsfr ADC0_CHCTR1;                      /* Channel 1 Control Register */

_xsfr ADC0_CHCTR2;                      /* Channel 2 Control Register */

_xsfr ADC0_CHCTR3;                      /* Channel 3 Control Register */

_xsfr ADC0_CHCTR4;                      /* Channel 4 Control Register */

_xsfr ADC0_CHCTR5;                      /* Channel 5 Control Register */

_xsfr ADC0_CHCTR6;                      /* Channel 6 Control Register */

_xsfr ADC0_CHCTR7;                      /* Channel 7 Control Register */

_xsfr ADC0_CHCTR8;                      /* Channel 8 Control Register */

_xsfr ADC0_CHCTR9;                      /* Channel 9 Control Register */

_xsfr ADC0_CHCTR10;                     /* Channel 10 Control Register */

_xsfr ADC0_CHCTR11;                     /* Channel 11 Control Register */

_xsfr ADC0_CHCTR12;                     /* Channel 12 Control Register */

_xsfr ADC0_CHCTR13;                     /* Channel 13 Control Register */

_xsfr ADC0_CHCTR14;                     /* Channel 14 Control Register */

_xsfr ADC0_CHCTR15;                     /* Channel 15 Control Register */

_xsfr ADC0_CHCTR16;                     /* Channel 16 Control Register */

_xsfr ADC0_CHCTR17;                     /* Channel 17 Control Register */

_xsfr ADC0_CHCTR18;                     /* Channel 18 Control Register */

_xsfr ADC0_CHCTR19;                     /* Channel 19 Control Register */

_xsfr ADC0_CHCTR20;                     /* Channel 20 Control Register */

_xsfr ADC0_CHCTR21;                     /* Channel 21 Control Register */

_xsfr ADC0_INPCR0;                      /* Input Class Register 0 */

_xsfr ADC0_INPCR1;                      /* Input Class Register 1 */

_xsfr ADC0_LCBR0;                       /* Limit Check Boundary Register 0 */

_xsfr ADC0_LCBR1;                       /* Limit Check Boundary Register 1 */

_xsfr ADC0_LCBR2;                       /* Limit Check Boundary Register 2 */

_xsfr ADC0_LCBR3;                       /* Limit Check Boundary Register 3 */

_xsfr ADC0_BFCR;                        /* Boundary Flag Control Register */

_xsfr ADC0_ALR0;                        /* Alias Register 0 */

_xsfr ADC0_RESR0;                       /* Result Register 0 */

_xsfr ADC0_RESR1;                       /* Result Register 1 */

_xsfr ADC0_RESR2;                       /* Result Register 2 */

_xsfr ADC0_RESR3;                       /* Result Register 3 */

_xsfr ADC0_RESR4;                       /* Result Register 4 */

_xsfr ADC0_RESR5;                       /* Result Register 5 */

_xsfr ADC0_RESR6;                       /* Result Register 6 */

_xsfr ADC0_RESR7;                       /* Result Register 7 */

_xsfr ADC0_RESRV0;                      /* Result Register 0, View V */

_xsfr ADC0_RESRV1;                      /* Result Register 1, View V */

_xsfr ADC0_RESRV2;                      /* Result Register 2, View V */

_xsfr ADC0_RESRV3;                      /* Result Register 3, View V */

_xsfr ADC0_RESRV4;                      /* Result Register 4, View V */

_xsfr ADC0_RESRV5;                      /* Result Register 5, View V */

_xsfr ADC0_RESRV6;                      /* Result Register 6, View V */

_xsfr ADC0_RESRV7;                      /* Result Register 7, View V */

_xsfr ADC0_RESRA0;                      /* Result Register 0, View A */

_xsfr ADC0_RESRA1;                      /* Result Register 1, View A */

_xsfr ADC0_RESRA2;                      /* Result Register 2, View A */

_xsfr ADC0_RESRA3;                      /* Result Register 3, View A */

_xsfr ADC0_RESRA4;                      /* Result Register 4, View A */

_xsfr ADC0_RESRA5;                      /* Result Register 5, View A */

_xsfr ADC0_RESRA6;                      /* Result Register 6, View A */

_xsfr ADC0_RESRA7;                      /* Result Register 7, View A */

_xsfr ADC0_RESRAV0;                     /* Result Register 0, View AV */

_xsfr ADC0_RESRAV1;                     /* Result Register 1, View AV */

_xsfr ADC0_RESRAV2;                     /* Result Register 2, View AV */

_xsfr ADC0_RESRAV3;                     /* Result Register 3, View AV */

_xsfr ADC0_RESRAV4;                     /* Result Register 4, View AV */

_xsfr ADC0_RESRAV5;                     /* Result Register 5, View AV */

_xsfr ADC0_RESRAV6;                     /* Result Register 6, View AV */

_xsfr ADC0_RESRAV7;                     /* Result Register 7, View AV */

_xsfr ADC0_RSSR;                        /* Result Status Shadow Register */

_xsfr ADC0_RCR0;                        /* Result Control Register 0 */

_xsfr ADC0_RCR1;                        /* Result Control Register 1 */

_xsfr ADC0_RCR2;                        /* Result Control Register 2 */

_xsfr ADC0_RCR3;                        /* Result Control Register 3 */

_xsfr ADC0_RCR4;                        /* Result Control Register 4 */

_xsfr ADC0_RCR5;                        /* Result Control Register 5 */

_xsfr ADC0_RCR6;                        /* Result Control Register 6 */

_xsfr ADC0_RCR7;                        /* Result Control Register 7 */

_xsfr ADC0_VFR;                         /* Valid Flag Register */

_xsfr ADC0_BWDENR;                      /* Broken Wire Detection Enable Reg. */

_xsfr ADC0_BWDENRE;                     /* Broken Wire Detection Enable Register Extended */

_xsfr ADC0_BWDCFGR;                     /* Broken Wire Detection Configuration Register */

_xsfr ADC0_EMENR;                       /* External Multiplexer Enable Register */

_xsfr ADC0_EMCTR;                       /* External Multiplexer Control Register */

_xsfr ADC0_EVINFR;                      /* Event Indication Flag Register */

_xsfr ADC0_EVINCR;                      /* Event Indication Clear Register */

_xsfr ADC0_CHINFR;                      /* Channel Event Indication Flag Register */

_xsfr ADC0_CHINFRE;                     /* Channel Event Indication Flag Register Extended */

_xsfr ADC0_CHINCR;                      /* Channel Event Indication Clear Register */

_xsfr ADC0_CHINCRE;                     /* Channel Event Indication Clear Register Extended */

_xsfr ADC0_EVINPR0;                     /* Event Interrupt Node Pointer Register 0 */

_xsfr ADC0_EVINPR8;                     /* Event Interrupt Node Pointer Register 8 */

_xsfr ADC0_EVINPR12;                    /* Event Interrupt Node Pointer Register 12 */

_xsfr ADC0_CHINPR0;                     /* Channel Intr. Node Pointer Reg. 0 */

_xsfr ADC0_CHINPR4;                     /* Channel Intr. Node Pointer Reg. 4 */

_xsfr ADC0_CHINPR8;                     /* Channel Intr. Node Pointer Reg. 8 */

_xsfr ADC0_CHINPR12;                    /* Channel Interrupt Node Pointer Register 12 */

_xsfr ADC0_CHINPR16;                    /* Channel Interrupt Node Pointer Register 16 */

_xsfr ADC0_CHINPR20;                    /* Channel Interrupt Node Pointer Register 20 */

#endif /* REGXC2310S_NOADC */

/********************************************************************************
 * PORTS
********************************************************************************/
#ifndef REGXC2310S_NOPORTS

_xsfr P2_POCON;                         /* Port 2 Output Control Register */

_xsfr P6_POCON;                         /* Port x Output Control Register */

_xsfr P10_POCON;                        /* Port 10 Output Control Register */

_sfr P2_OUT;                            /* Port 2 Output Register */
_sfrbit P2_OUT_P0;                      /* P2_OUT.0: Port Output Bit x */
_sfrbit P2_OUT_P1;                      /* P2_OUT.1: Port Output Bit x */
_sfrbit P2_OUT_P2;                      /* P2_OUT.2: Port Output Bit x */
_sfrbit P2_OUT_P3;                      /* P2_OUT.3: Port Output Bit x */
_sfrbit P2_OUT_P4;                      /* P2_OUT.4: Port Output Bit x */
_sfrbit P2_OUT_P5;                      /* P2_OUT.5: Port Output Bit x */
_sfrbit P2_OUT_P6;                      /* P2_OUT.6: Port Output Bit x */
_sfrbit P2_OUT_P7;                      /* P2_OUT.7: Port Output Bit x */
_sfrbit P2_OUT_P8;                      /* P2_OUT.8: Port Output Bit x */
_sfrbit P2_OUT_P9;                      /* P2_OUT.9: Port Output Bit x */
_sfrbit P2_OUT_P10;                     /* P2_OUT.10: Port Output Bit x */
_sfrbit P2_OUT_P11;                     /* P2_OUT.11: Port Output Bit x */
_sfrbit P2_OUT_P12;                     /* P2_OUT.12: Port Output Bit x */
_sfrbit P2_OUT_P13;                     /* P2_OUT.13: Port Output Bit x */
_sfrbit P2_OUT_P14;                     /* P2_OUT.14: Port Output Bit x */
_sfrbit P2_OUT_P15;                     /* P2_OUT.15: Port Output Bit x */

_sfr P6_OUT;                            /* Port n Output Register */
_sfrbit P6_OUT_P0;                      /* P6_OUT.0: Port Output Bit x */
_sfrbit P6_OUT_P1;                      /* P6_OUT.1: Port Output Bit x */
_sfrbit P6_OUT_P2;                      /* P6_OUT.2: Port Output Bit x */
_sfrbit P6_OUT_P3;                      /* P6_OUT.3: Port Output Bit x */
_sfrbit P6_OUT_P4;                      /* P6_OUT.4: Port Output Bit x */
_sfrbit P6_OUT_P5;                      /* P6_OUT.5: Port Output Bit x */
_sfrbit P6_OUT_P6;                      /* P6_OUT.6: Port Output Bit x */
_sfrbit P6_OUT_P7;                      /* P6_OUT.7: Port Output Bit x */
_sfrbit P6_OUT_P8;                      /* P6_OUT.8: Port Output Bit x */
_sfrbit P6_OUT_P9;                      /* P6_OUT.9: Port Output Bit x */
_sfrbit P6_OUT_P10;                     /* P6_OUT.10: Port Output Bit x */
_sfrbit P6_OUT_P11;                     /* P6_OUT.11: Port Output Bit x */
_sfrbit P6_OUT_P12;                     /* P6_OUT.12: Port Output Bit x */
_sfrbit P6_OUT_P13;                     /* P6_OUT.13: Port Output Bit x */
_sfrbit P6_OUT_P14;                     /* P6_OUT.14: Port Output Bit x */
_sfrbit P6_OUT_P15;                     /* P6_OUT.15: Port Output Bit x */

_sfr P10_OUT;                           /* Port 10 Output Register */
_sfrbit P10_OUT_P0;                     /* P10_OUT.0: Port Output Bit x */
_sfrbit P10_OUT_P1;                     /* P10_OUT.1: Port Output Bit x */
_sfrbit P10_OUT_P2;                     /* P10_OUT.2: Port Output Bit x */
_sfrbit P10_OUT_P3;                     /* P10_OUT.3: Port Output Bit x */
_sfrbit P10_OUT_P4;                     /* P10_OUT.4: Port Output Bit x */
_sfrbit P10_OUT_P5;                     /* P10_OUT.5: Port Output Bit x */
_sfrbit P10_OUT_P6;                     /* P10_OUT.6: Port Output Bit x */
_sfrbit P10_OUT_P7;                     /* P10_OUT.7: Port Output Bit x */
_sfrbit P10_OUT_P8;                     /* P10_OUT.8: Port Output Bit x */
_sfrbit P10_OUT_P9;                     /* P10_OUT.9: Port Output Bit x */
_sfrbit P10_OUT_P10;                    /* P10_OUT.10: Port Output Bit x */
_sfrbit P10_OUT_P11;                    /* P10_OUT.11: Port Output Bit x */
_sfrbit P10_OUT_P12;                    /* P10_OUT.12: Port Output Bit x */
_sfrbit P10_OUT_P13;                    /* P10_OUT.13: Port Output Bit x */
_sfrbit P10_OUT_P14;                    /* P10_OUT.14: Port Output Bit x */
_sfrbit P10_OUT_P15;                    /* P10_OUT.15: Port Output Bit x */

_xsfr P2_OMRH;                          /* Port 2 Output Modification Register High */

_xsfr P10_OMRH;                         /* Port 10 Output Modification Register High */

_xsfr P2_OMRL;                          /* Port 2 Output Modification Register Low */

_xsfr P6_OMRL;                          /* Port n Output Modification Register Low */

_xsfr P10_OMRL;                         /* Port 10 Output Modification Register Low */

_sfr P2_IN;                             /* Port n Input Register */
_sfrbit P2_IN_P0;                       /* P2_IN.0: Port Input Bit x */
_sfrbit P2_IN_P1;                       /* P2_IN.1: Port Input Bit x */
_sfrbit P2_IN_P2;                       /* P2_IN.2: Port Input Bit x */
_sfrbit P2_IN_P3;                       /* P2_IN.3: Port Input Bit x */
_sfrbit P2_IN_P4;                       /* P2_IN.4: Port Input Bit x */
_sfrbit P2_IN_P5;                       /* P2_IN.5: Port Input Bit x */
_sfrbit P2_IN_P6;                       /* P2_IN.6: Port Input Bit x */
_sfrbit P2_IN_P7;                       /* P2_IN.7: Port Input Bit x */
_sfrbit P2_IN_P8;                       /* P2_IN.8: Port Input Bit x */
_sfrbit P2_IN_P9;                       /* P2_IN.9: Port Input Bit x */
_sfrbit P2_IN_P10;                      /* P2_IN.10: Port Input Bit x */
_sfrbit P2_IN_P11;                      /* P2_IN.11: Port Input Bit x */
_sfrbit P2_IN_P12;                      /* P2_IN.12: Port Input Bit x */
_sfrbit P2_IN_P13;                      /* P2_IN.13: Port Input Bit x */
_sfrbit P2_IN_P14;                      /* P2_IN.14: Port Input Bit x */
_sfrbit P2_IN_P15;                      /* P2_IN.15: Port Input Bit x */

_sfr P5_IN;                             /* Port 5 Input Register */
_sfrbit P5_IN_P0;                       /* P5_IN.0: Port Input Bit x */
_sfrbit P5_IN_P1;                       /* P5_IN.1: Port Input Bit x */
_sfrbit P5_IN_P2;                       /* P5_IN.2: Port Input Bit x */
_sfrbit P5_IN_P3;                       /* P5_IN.3: Port Input Bit x */
_sfrbit P5_IN_P4;                       /* P5_IN.4: Port Input Bit x */
_sfrbit P5_IN_P5;                       /* P5_IN.5: Port Input Bit x */
_sfrbit P5_IN_P6;                       /* P5_IN.6: Port Input Bit x */
_sfrbit P5_IN_P7;                       /* P5_IN.7: Port Input Bit x */
_sfrbit P5_IN_P8;                       /* P5_IN.8: Port Input Bit x */
_sfrbit P5_IN_P9;                       /* P5_IN.9: Port Input Bit x */
_sfrbit P5_IN_P10;                      /* P5_IN.10: Port Input Bit x */
_sfrbit P5_IN_P11;                      /* P5_IN.11: Port Input Bit x */
_sfrbit P5_IN_P12;                      /* P5_IN.12: Port Input Bit x */
_sfrbit P5_IN_P13;                      /* P5_IN.13: Port Input Bit x */
_sfrbit P5_IN_P14;                      /* P5_IN.14: Port Input Bit x */
_sfrbit P5_IN_P15;                      /* P5_IN.15: Port Input Bit x */

_sfr P6_IN;                             /* Port 6 Input Register */
_sfrbit P6_IN_P0;                       /* P6_IN.0: Port Input Bit x */
_sfrbit P6_IN_P1;                       /* P6_IN.1: Port Input Bit x */
_sfrbit P6_IN_P2;                       /* P6_IN.2: Port Input Bit x */
_sfrbit P6_IN_P3;                       /* P6_IN.3: Port Input Bit x */
_sfrbit P6_IN_P4;                       /* P6_IN.4: Port Input Bit x */
_sfrbit P6_IN_P5;                       /* P6_IN.5: Port Input Bit x */
_sfrbit P6_IN_P6;                       /* P6_IN.6: Port Input Bit x */
_sfrbit P6_IN_P7;                       /* P6_IN.7: Port Input Bit x */
_sfrbit P6_IN_P8;                       /* P6_IN.8: Port Input Bit x */
_sfrbit P6_IN_P9;                       /* P6_IN.9: Port Input Bit x */
_sfrbit P6_IN_P10;                      /* P6_IN.10: Port Input Bit x */
_sfrbit P6_IN_P11;                      /* P6_IN.11: Port Input Bit x */
_sfrbit P6_IN_P12;                      /* P6_IN.12: Port Input Bit x */
_sfrbit P6_IN_P13;                      /* P6_IN.13: Port Input Bit x */
_sfrbit P6_IN_P14;                      /* P6_IN.14: Port Input Bit x */
_sfrbit P6_IN_P15;                      /* P6_IN.15: Port Input Bit x */

_sfr P10_IN;                            /* Port 10 Input Register */
_sfrbit P10_IN_P0;                      /* P10_IN.0: Port Input Bit x */
_sfrbit P10_IN_P1;                      /* P10_IN.1: Port Input Bit x */
_sfrbit P10_IN_P2;                      /* P10_IN.2: Port Input Bit x */
_sfrbit P10_IN_P3;                      /* P10_IN.3: Port Input Bit x */
_sfrbit P10_IN_P4;                      /* P10_IN.4: Port Input Bit x */
_sfrbit P10_IN_P5;                      /* P10_IN.5: Port Input Bit x */
_sfrbit P10_IN_P6;                      /* P10_IN.6: Port Input Bit x */
_sfrbit P10_IN_P7;                      /* P10_IN.7: Port Input Bit x */
_sfrbit P10_IN_P8;                      /* P10_IN.8: Port Input Bit x */
_sfrbit P10_IN_P9;                      /* P10_IN.9: Port Input Bit x */
_sfrbit P10_IN_P10;                     /* P10_IN.10: Port Input Bit x */
_sfrbit P10_IN_P11;                     /* P10_IN.11: Port Input Bit x */
_sfrbit P10_IN_P12;                     /* P10_IN.12: Port Input Bit x */
_sfrbit P10_IN_P13;                     /* P10_IN.13: Port Input Bit x */
_sfrbit P10_IN_P14;                     /* P10_IN.14: Port Input Bit x */
_sfrbit P10_IN_P15;                     /* P10_IN.15: Port Input Bit x */

_xsfr P2_IOCR00;                        /* Port 2 Input/Output Control Register 00 */

_xsfr P2_IOCR01;                        /* Port 2 Input/Output Control Register 01 */

_xsfr P2_IOCR02;                        /* Port 2 Input/Output Control Register 02 */

_xsfr P2_IOCR03;                        /* Port 2 Input/Output Control Register 03 */

_xsfr P2_IOCR04;                        /* Port 2 Input/Output Control Register 04 */

_xsfr P2_IOCR05;                        /* Port 2 Input/Output Control Register 05 */

_xsfr P2_IOCR06;                        /* Port 2 Input/Output Control Register 06 */

_xsfr P2_IOCR07;                        /* Port 2 Input/Output Control Register 07 */

_xsfr P2_IOCR08;                        /* Port 2 Input/Output Control Register 08 */

_xsfr P2_IOCR09;                        /* Port 2 Input/Output Control Register 09 */

_xsfr P2_IOCR10;                        /* Port 2 Input/Output Control Register 10 */

_xsfr P2_IOCR13;                        /* Port 2 Input/Output Control Register 13 */

_xsfr P6_IOCR00;                        /* Port 6 Input/Output Control Register 00 */

_xsfr P6_IOCR01;                        /* Port 6 Input/Output Control Register 01 */

_xsfr P6_IOCR03;                        /* Port 6 Input/Output Control Register 03 */

_xsfr P10_IOCR00;                       /* Port 10 Input/Output Control Register 00 */

_xsfr P10_IOCR01;                       /* Port 10 Input/Output Control Register 01 */

_xsfr P10_IOCR02;                       /* Port 10 Input/Output Control Register 02 */

_xsfr P10_IOCR03;                       /* Port 10 Input/Output Control Register 03 */

_xsfr P10_IOCR04;                       /* Port 10 Input/Output Control Register 04 */

_xsfr P10_IOCR05;                       /* Port 10 Input/Output Control Register 05 */

_xsfr P10_IOCR06;                       /* Port 10 Input/Output Control Register 06 */

_xsfr P10_IOCR07;                       /* Port 10 Input/Output Control Register 07 */

_xsfr P10_IOCR08;                       /* Port 10 Input/Output Control Register 08 */

_xsfr P10_IOCR09;                       /* Port 10 Input/Output Control Register 09 */

_xsfr P10_IOCR10;                       /* Port 10 Input/Output Control Register 10 */

_xsfr P10_IOCR12;                       /* Port 10 Input/Output Control Register 12 */

_xsfr P2_DIDIS;                         /* Port 2 Digital Input Disable Register */

_sfr P5_DIDIS;                          /* Port 5 Digital Input Disable Register */

_sfr P6_DIDIS;                          /* Port 6 Digital Input Disable Register */
#endif /* REGXC2310S_NOPORTS */
#endif /* REGXC2310S_INC */
